package com.alpha.lagouapk.ui.home.v2

import android.content.Context
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.PositionInfo
import com.alpha.lagouapk.ui.home.promotion.HomeActivityPositionVH
import com.alpha.lagouapk.ui.home.v2.HomePositionAdapter.AD_POSITION
import com.alpha.lagouapk.ui.home.v2.HomePositionAdapter.EMPTY_VIEW
import com.alpha.lagouapk.ui.home.v2.HomePositionAdapter.HOME_HEADER
import com.alpha.lagouapk.ui.home.v2.HomePositionAdapter.POSITION
import com.alpha.lagouapk.ui.home.v2.HomePositionAdapter.POSITION_ACTIVITY
import com.alpha.lagouapk.ui.home.v2.manager.analytic.HomePositionAnalyticManager
import com.alpha.lagouapk.ui.home.v2.manager.business.HomePositionManager
import com.alpha.lagouapk.widget.behavior.HomeActivityCardManager
import com.common.adapter.viewholder.BaseVHAdapter
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.component.ui.emptyPage.DefaultEmptyLayout
import java.util.Objects

class HomeOverseaAdapter(val context: Context, mPositionData:MutableList<PositionInfo>?,
                         val mExpectJobId:Int, val mSource:Int,
                         private val mOnFilterConfirm:((Map<String?,List<String>?>) -> Unit)?): BaseVHAdapter<PositionInfo>(context){
    private var isShowEmptyView = false
    private var recyclerView: RecyclerView? = null
    private var isUpdateHeadAdView = true
    init {
        this.mBeans = mPositionData
    }

    override fun onAttachedToRecyclerView(recyclerView: RecyclerView) {
        super.onAttachedToRecyclerView(recyclerView)
        this.recyclerView = recyclerView
    }

    override fun onViewAttachedToWindow(holder: RecyclerView.ViewHolder) {
        super.onViewAttachedToWindow(holder)
        if (holder.itemView is HomeOverseaHeadView) {
            val headView = holder.itemView
            headView.post {
                val view = Objects.requireNonNull<RecyclerView.LayoutManager>(recyclerView?.layoutManager).findViewByPosition(1)
                if (view is DefaultEmptyLayout) {
                    val emptyViewHeight: Int = recyclerView?.height?.minus(headView.height) ?: view.height
                    val emptyLayoutParams = view.getLayoutParams()
                    emptyLayoutParams.height = emptyViewHeight
                    view.setLayoutParams(emptyLayoutParams)
                }
            }
        }
    }

    override fun getItemCount(): Int = super.getItemCount() + if (isShowEmptyView) 1 else 0

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        when(holder.itemView){
            is HomeOverseaHeadView -> {
                if (!isUpdateHeadAdView) {
                    return
                }
                (holder.itemView as HomeOverseaHeadView).setHeadData(HomeActivityCardManager.getInstance().getOverseaConfig(mExpectJobId))
            }
            is DefaultEmptyLayout -> {
                (holder.itemView as DefaultEmptyLayout).setContent(ResourceUtils.getString(R.string.msg_no_record_no_filter_oversea))
            }
            is HomePositionView -> {
                val positionInfo = getItem(position) as? PositionInfo ?: return
                (holder.itemView as HomePositionView).setData(positionInfo)
                holder.itemView.setOnClickListener{
                    HomePositionManager.onClickHomePositionView(mContext, positionInfo.sourceFrom, positionInfo, data, positionInfo.pd_positionId, mExpectJobId)
                }
                HomePositionAnalyticManager.getInstance().setPositionShowAnalytic(positionInfo.sourceFrom, positionInfo, getRealPosition(position).toString() + "")
            }
        }

    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        var viewHolder:RecyclerView.ViewHolder = super.onCreateViewHolder(parent, viewType)
        when(viewType){
            HOME_HEADER -> viewHolder = HomeActivityPositionVH(HomeOverseaHeadView(context).setOnConfirmListener(mOnFilterConfirm))
            EMPTY_VIEW ->{
                val emptyLayout:DefaultEmptyLayout = DefaultEmptyLayout(context).apply {
                    setBackgroundResource(R.drawable.shape_white_r4)
                    setSubTitle(ResourceUtils.getString(R.string.no_recommend_position_2))
                    setTopImageMarginTop(ResourceUtils.getDimenSize(R.dimen.dp_50))
                    setImageResource(R.drawable.blank_job_360x292)
                }
                emptyLayout.layoutParams = ViewGroup.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT)
                viewHolder = HomeActivityPositionVH(emptyLayout)
            }
            POSITION,POSITION_ACTIVITY,AD_POSITION -> {
                viewHolder = HomeActivityPositionVH(HomePositionView(context));
            }
        }

        return viewHolder
    }

    override fun getItemViewType(position: Int): Int {
        if (mIsHasHeader && position == 0) {
            return HOME_HEADER
        }
        if (isShowEmptyView && ((mIsHasHeader && position == 1) || (!mIsHasHeader && position == 0))) {
            return EMPTY_VIEW
        }
        val item = getItem(position)
        return if (item is PositionInfo) { item.pd_type } else { R.layout.list_footer_view }
    }

    fun showEmptyView(isEmpty: Boolean) {
        isShowEmptyView = isEmpty
    }
    fun setNotifyHead(isNotify: Boolean) {
        isUpdateHeadAdView = isNotify
    }
    private fun getRealPosition(adapterPosition: Int): Int {
        return if (mIsHasHeader) adapterPosition - 1 else adapterPosition
    }
}