package com.alpha.lagouapk.ui.home.v2

import android.content.Context
import android.util.AttributeSet
import android.util.TypedValue
import android.view.Gravity
import android.view.View
import android.widget.FrameLayout
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.FilterData
import com.alpha.lagouapk.bean.FilterOptionData
import com.alpha.lagouapk.bean.HomeActivityConfigBean
import com.alpha.lagouapk.ui.home.v2.filter.FilterLevelTwoView
import com.alpha.lagouapk.ui.home.v2.filter.FilterLevelOneView
import com.alpha.lagouapk.ui.home.v2.filter.FilterLevelView
import com.alpha.lagouapk.ui.home.v2.filter.HomeFilterDialog
import com.alpha.lagouapk.ui.home.v2.filter.SelectLevel
import com.alpha.lagouapk.ui.home.v2.filter.SelectType
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.imageload.glide.transform.RoundTransform
import com.lagou.commonlibs.utils.DeviceUtils
import com.lagou.commonlibs.utils.ImageUrlUtils
import com.lagou.commonlibs.utils.ResourceUtils
import kotlinx.android.synthetic.main.view_oversear_head.view.iv_oversea_activity

/**
 * 首页出海活动头部view
 */
class HomeOverseaHeadView @JvmOverloads constructor(
    context: Context,
    attrs: AttributeSet? = null,
    defStyleAttr: Int = 0
) : FrameLayout(context, attrs, defStyleAttr) {
   private lateinit var mFilterViewContainer:LinearLayout
   private lateinit var mIvOverseaCover:ImageView
   private var mSelectOptionMap:HashMap<String?,List<FilterOptionData>?> = HashMap(2)
    private var mOnConfirmListener: ((Map<String?,List<String>?>) -> Unit)? = null
   companion object{
       const val TAG_TITLE = "tabTitle"
       const val TAG_ICON = "tabIcon"
   }
    init {
        inflate(context, R.layout.view_oversear_head,this)
        initView()
    }

    private fun initView() {
        mFilterViewContainer = findViewById(R.id.ll_filter_container)
        mIvOverseaCover = findViewById(R.id.iv_oversea_activity)
       val params = (mIvOverseaCover.layoutParams as LinearLayout.LayoutParams).apply {
           width = DeviceUtils.getScreenWidth() - ResourceUtils.getDimenSize(R.dimen.dp_30)
           height = (width * 165f / 345).toInt()
       }
        mIvOverseaCover.layoutParams = params
    }

    fun setHeadData(config:HomeActivityConfigBean?){
        mFilterViewContainer.removeAllViews()
        ImageLoadUtils.with(context)
            .load<String>(ImageUrlUtils.getLagouImageUrl(config?.activityBackgroundImg))
            .bitmapTransform(RoundTransform(4))
            .dontAnimate()
            .into(iv_oversea_activity)
        val options = config?.selectConfigList
        mFilterViewContainer.visibility = if (options.isNullOrEmpty()) View.GONE else View.VISIBLE
        options?.forEachIndexed { index, filterData ->
            val tabMarginRight = if (index != options.size - 1) ResourceUtils.getDimenSize(R.dimen.dp_10) else 0
            val tabView = generateOptionTab(filterData.selectName, tabMarginRight)
            setTabTitle(tabView,filterData,mSelectOptionMap[filterData.selectKey])
            mFilterViewContainer.addView(tabView)
            tabView.setOnClickListener { onTabClick(tabView,filterData) }
        }
    }

    /**
     * tab点击事件
     */
    private fun onTabClick(tabView:LinearLayout,filterData:FilterData){
        val filterView = getFilterContentView(filterData.selectLevel)?.apply {
            val dialog = HomeFilterDialog(context,this)
            dialog.show()
            setFilterData(filterData,mSelectOptionMap[filterData.selectKey])
            setOnCloseListener { dialog.dismiss() }
            setOnConfirmListener {selectOption ->
                val filterSelection = selectOption?.filter { it.selectValue != ResourceUtils.getString(R.string.no_limit) }
                mSelectOptionMap[filterData.selectKey] = filterSelection
                setTabTitle(tabView,filterData,filterSelection)
                dialog.dismiss()
               val selectMap = mSelectOptionMap.mapValues { it.value?.map { filterOptionData -> filterOptionData.selectValue ?: "" } }
                mOnConfirmListener?.invoke(selectMap)
            }
        }
        AnalyticHelper.getInstance().sendClickInfo("ea00",if (filterView is FilterLevelOneView) "r1ui4" else "s1ui5")
    }

    fun setOnConfirmListener(onConfirmListener:((Map<String?,List<String>?>) -> Unit)?):HomeOverseaHeadView{
        this.mOnConfirmListener = onConfirmListener
        return this
    }


    /**
     * 设置tab标题
     */
    private fun setTabTitle(tabView:LinearLayout,filterData: FilterData,selectOption: List<FilterOptionData>?) {
        var tvTitle:TextView? = null
        var ivTitleIcon:ImageView? = null
        for (i in 0 until tabView.childCount){
            val childView = tabView.getChildAt(i)
            if (childView is TextView && childView.tag == TAG_TITLE){
                tvTitle = childView
                continue
            }
            if (childView is ImageView && childView.tag == TAG_ICON){
                ivTitleIcon = childView
                continue
            }
        }
        val isDefault = selectOption.isNullOrEmpty()
        if (isDefault){
            tvTitle?.text = filterData.selectName
            tvTitle?.setTextColor(ResourceUtils.getColor(R.color.color_666666))
            ivTitleIcon?.setColorFilter(ResourceUtils.getColor(R.color.color_999))
            return
        }
        tvTitle?.setTextColor(ResourceUtils.getColor(R.color.color_00b38a))
        ivTitleIcon?.setColorFilter(ResourceUtils.getColor(R.color.color_00b38a))
        val tabTitle = if (filterData.selectType == SelectType.CheckBox.type) "${filterData.selectTitle} ${selectOption!!.size}" else "${selectOption!![0].selectValue}"
        tvTitle?.text = tabTitle
    }


    /**
     * 根据筛选器层级选择对应的筛选器内容区
     * 目前只适配最多两层
     */
    private fun getFilterContentView(filterLevel:Int): FilterLevelView?{
        var filterContentView: FilterLevelView? = null
        when(filterLevel){
            SelectLevel.One.selectLevel -> {
                filterContentView = FilterLevelOneView(context)
            }
            SelectLevel.Two.selectLevel -> {
                filterContentView = FilterLevelTwoView(context)
            }
        }
        return filterContentView
    }

    private fun generateOptionTab(tabTitle:String?,tabMarginRight:Int):LinearLayout{
        val tabContainer = LinearLayout(context).apply {
            orientation = LinearLayout.HORIZONTAL
            layoutParams = LinearLayout.LayoutParams(LinearLayout.LayoutParams.WRAP_CONTENT,ResourceUtils.getDimenSize(R.dimen.dp_28)).apply {
                marginEnd = tabMarginRight
            }
            gravity = Gravity.CENTER
            val dp10 = ResourceUtils.getDimenSize(R.dimen.dp_10)
            setPadding(dp10,0,dp10,0)
            setBackgroundResource(R.drawable.shape_f8f9fa_r2)
        }
        val tabTitle = TextView(context).apply {
            tag = TAG_TITLE
            setTextColor(ResourceUtils.getColor(R.color.color_666666))
            setTextSize(TypedValue.COMPLEX_UNIT_SP,12f)
            layoutParams = LinearLayout.LayoutParams(LinearLayout.LayoutParams.WRAP_CONTENT,LinearLayout.LayoutParams.WRAP_CONTENT)
            text = tabTitle
        }
        val tabIcon = ImageView(context).apply {
            tag = TAG_ICON
            val dp5 = ResourceUtils.getDimenSize(R.dimen.dp_5)
            val dp3 = ResourceUtils.getDimenSize(R.dimen.dp_3)
            layoutParams = LinearLayout.LayoutParams(dp5,dp5).apply {
                leftMargin = dp3
                topMargin = dp3
            }
            setImageResource(R.drawable.screening_ic_arrow_nor)
            setColorFilter(ResourceUtils.getColor(R.color.color_999))
        }
        tabContainer.addView(tabTitle)
        tabContainer.addView(tabIcon)
        return tabContainer;
    }
}