package com.alpha.lagouapk.ui.home.v2.filter

import android.annotation.SuppressLint
import android.content.Context
import android.util.AttributeSet
import android.util.SparseBooleanArray
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.ImageView
import android.widget.TextView
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import butterknife.ButterKnife
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.FilterData
import com.alpha.lagouapk.bean.FilterOptionData
import com.common.widget.decoration.GridItemDecoration
import com.lagou.commonlibs.imageload.ImageLoadUtils
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.view.LTitleBarLayout

/**
 * 只有一级数据的筛选器
 */
class FilterLevelOneView @JvmOverloads constructor(
    context: Context, attrs: AttributeSet? = null,
    defStyleAttr: Int = 0
) : FilterLevelView(context,attrs,defStyleAttr) {
    @BindView(R.id.title_bar_filter)
    lateinit var mTitleBar:LTitleBarLayout
    @BindView(R.id.tv_filter_title)
    lateinit var mTvTitle:TextView
    @BindView(R.id.recycler_view_filter)
    lateinit var mRecyclerView:RecyclerView
    @BindView(R.id.filter_clear)
    lateinit var mBtnReset: Button
    @BindView(R.id.filter_confirm)
    lateinit var mBtnConfirm: Button
    private var mFilterAdapter:FilterOptionAdapter? = null
    private var mOnConfirmClickListener:((List<FilterOptionData>?)->Unit)? = null//点击确认
    private var mOnCloseClickListener:(()->Unit)? = null//点击关闭
    private var mSelectType:String = SelectType.CheckBox.type
    init {
        inflate(context, R.layout.filter_level_single,this)
        ButterKnife.bind(this)
        this.initListener()
        this.initView()
    }

    private fun initView() {
        val layoutManager = GridLayoutManager(context, 3)
        mRecyclerView.layoutManager = layoutManager
        mRecyclerView.setHasFixedSize(true)
        mRecyclerView.addItemDecoration(GridItemDecoration(ResourceUtils.getDimenSize(R.dimen.dp_10),3))
        mFilterAdapter = FilterOptionAdapter(context) {
            showSelectNum()
        }
        mRecyclerView.adapter = mFilterAdapter
    }

    /**
     * 关闭事件回调
     */
    override fun setOnCloseListener(onCloseListener:(()->Unit)?){
        this.mOnCloseClickListener = onCloseListener
    }

    /**
     * 确定事件回调
     */
    override fun setOnConfirmListener(onConfirmListener:((List<FilterOptionData>?)->Unit)?){
        this.mOnConfirmClickListener = onConfirmListener
    }

    /**
     * 展示选中的数量
     */
    private fun showSelectNum() {
        if (mSelectType != SelectType.CheckBox.type){
            //只有在多选时才设置数字
            return
        }
        val selectNum = mFilterAdapter?.getSelectOption(true)?.size
        mBtnConfirm.text = if (selectNum == 0) ResourceUtils.getString(R.string.ok) else "${ResourceUtils.getString(R.string.ok)} $selectNum"
    }

    @SuppressLint("NotifyDataSetChanged")
    private fun initListener() {
        mTitleBar.setLeftImgListener {
            mOnCloseClickListener?.invoke()
        }
        mBtnReset.setOnClickListener {
            mFilterAdapter?.resetSelect()
            mFilterAdapter?.notifyDataSetChanged()
            showSelectNum()
        }
        mBtnConfirm.setOnClickListener {
            mOnConfirmClickListener?.invoke(mFilterAdapter?.getSelectOption(false))
        }

    }

    override fun setFilterData(filterData: FilterData?, selectOptionData:List<FilterOptionData>?){
        this.mSelectType = filterData?.selectType ?: SelectType.CheckBox.type
        mTvTitle.text = filterData?.selectTitle
        mFilterAdapter?.setFilterOptionData(filterData?.selectValuesConfigs,selectOptionData)
        showSelectNum()
    }

    class FilterOptionAdapter(private val context:Context,private val onItemClick:(()->Unit)?): RecyclerView.Adapter<FilterOptionAdapter.FilterOptionViewHolder>() {
        private var filterOptionData:List<FilterOptionData>? = null
        private val optionSelectMap:SparseBooleanArray = SparseBooleanArray()
        class FilterOptionViewHolder(itemView: View): RecyclerView.ViewHolder(itemView) {
            val tvOption:TextView = itemView.findViewById(R.id.tv_option_content)
            val ivOptionIcon:ImageView = itemView.findViewById(R.id.iv_option_icon)
        }

        fun setFilterOptionData(filterOptionData:List<FilterOptionData>?, selectOptionData:List<FilterOptionData>?){
            this.filterOptionData = filterOptionData
            initSelectOption(selectOptionData)
            notifyDataSetChanged()
        }

        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): FilterOptionViewHolder {
            val itemView = LayoutInflater.from(context).inflate(R.layout.item_filter_option_simple,parent,false)
            val holder = FilterOptionViewHolder(itemView)
            itemView.setOnClickListener {
                onItemClick(holder.adapterPosition,holder.tvOption,holder.ivOptionIcon)
            }
            return holder
        }

        private fun onItemClick(position:Int,tvOption:TextView,ivOptionIcon:ImageView){
            var isExclusive = filterOptionData?.get(position)?.exclusive == true//是否互斥
            optionSelectMap.put(position,optionSelectMap.get(position).not())
            tvOption.isSelected = optionSelectMap.get(position)
            ivOptionIcon.alpha = if (tvOption.isSelected) 1f else 0.3f
            if (tvOption.isSelected){
                if (isExclusive){
                    //当前选中的与其他选项互斥，需要清空其它选项
                    val size = optionSelectMap.size()
                    for (i in 0 until size) {
                        if (i != position){
                            optionSelectMap.put(i,false)
                        }
                    }
                }else{
                    //需要将其他互斥项清空
                    filterOptionData?.forEachIndexed { index, optionData ->
                        if (optionData.exclusive){
                            optionSelectMap.put(index,false)
                        }
                    }
                }
                notifyDataSetChanged()
            }
            onItemClick?.invoke()
        }

        override fun getItemCount(): Int = filterOptionData?.size ?: 0

        override fun onBindViewHolder(holder: FilterOptionViewHolder, position: Int) {
            val optionData = filterOptionData?.get(position)
            holder.tvOption.text = optionData?.selectValue
            if (optionData?.selectValueFlag.isNullOrEmpty()){
                holder.ivOptionIcon.visibility = View.GONE
            }else{
                holder.ivOptionIcon.visibility = View.VISIBLE
                ImageLoadUtils.with(context).load(optionData!!.selectValueFlag).into(holder.ivOptionIcon)
            }
            holder.tvOption.isSelected = optionSelectMap.get(position)
            holder.ivOptionIcon.alpha = if (holder.tvOption.isSelected) 1f else 0.3f
        }

        fun resetSelect(){
            this.optionSelectMap.clear()
        }

        fun getSelectOption(isExcludeNoLimit:Boolean): List<FilterOptionData> {
            val selectOption = mutableListOf<FilterOptionData>()
            this.filterOptionData?.forEachIndexed { index, optionData ->
                if (optionSelectMap.get(index)){
                    if (isExcludeNoLimit.not() || isExcludeNoLimit && optionData.selectValue != ResourceUtils.getString(R.string.no_limit)){
                        selectOption.add(optionData)
                    }

                }
            }
            return selectOption
        }


        private fun initSelectOption(selectData:List<FilterOptionData>?) {
            optionSelectMap.clear()
            this.filterOptionData?.forEachIndexed { index, filterOptionData ->
                optionSelectMap.put(index,selectData?.contains(filterOptionData) == true)
            }
        }
    }
}