package com.alpha.lagouapk.ui.home.v2.filter

import android.annotation.SuppressLint
import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import butterknife.ButterKnife
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.FilterData
import com.alpha.lagouapk.bean.FilterOptionData
import com.common.widget.decoration.GridItemDecoration
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.view.LTitleBarLayout

/**
 * 二级数据的筛选器
 */
class FilterLevelTwoView @JvmOverloads constructor(
    context: Context, attrs: AttributeSet? = null,
    defStyleAttr: Int = 0
) : FilterLevelView(context,attrs,defStyleAttr) {
    @BindView(R.id.title_bar_filter)
    lateinit var mTitleBar:LTitleBarLayout
    @BindView(R.id.rv_first_filter)
    lateinit var mRvFirst: RecyclerView
    @BindView(R.id.rv_second_filter)
    lateinit var mRvSecond: RecyclerView
    private lateinit var mFirstAdapter:FirstFilterAdapter
    private lateinit var mSecondAdapter:SecondFilterAdapter
    private var mOnConfirmClickListener:((List<FilterOptionData>?)->Unit)? = null//点击确认
    private var mOnCloseClickListener:(()->Unit)? = null//点击关闭
    init {
        inflate(context, R.layout.filter_level_two,this)
        ButterKnife.bind(this)
        this.initView()
        this.initListener()
    }

    private fun initListener() {
        mTitleBar.setLeftImgListener {
            mOnCloseClickListener?.invoke()
        }
    }

    private fun initView() {
        mRvFirst.layoutManager = LinearLayoutManager(context)
        mRvSecond.layoutManager = GridLayoutManager(context, 3)
        mRvSecond.addItemDecoration(GridItemDecoration(ResourceUtils.getDimenSize(R.dimen.dp_10),3))
        mSecondAdapter = SecondFilterAdapter(context){
            val selectOptions = mutableListOf<FilterOptionData>()
            selectOptions.add(it)
            mOnConfirmClickListener?.invoke(selectOptions)
        }
        mFirstAdapter = FirstFilterAdapter(context){
            mSecondAdapter.setFilterOptionData(it.childSelectValues)
        }
        mRvFirst.adapter = mFirstAdapter
        mRvSecond.adapter = mSecondAdapter
    }


    override fun setOnCloseListener(onCloseListener: (() -> Unit)?) {
        this.mOnCloseClickListener = onCloseListener
    }

    override fun setFilterData(filterData: FilterData?, selectOptionData: List<FilterOptionData>?) {
        mTitleBar.setCenterTvTxt(filterData?.selectTitle)
        mFirstAdapter.setFilterOptionData(filterData?.selectValuesConfigs)
        mSecondAdapter.setFilterOptionData(filterData?.selectValuesConfigs?.get(0)?.childSelectValues)
    }

    override fun setOnConfirmListener(onConfirmListener: ((List<FilterOptionData>?) -> Unit)?) {
        this.mOnConfirmClickListener = onConfirmListener
    }

    class FirstFilterAdapter(val context: Context,private val onItemClick:((FilterOptionData)->Unit)?): RecyclerView.Adapter<FirstFilterAdapter.FirstFilterViewHolder>() {
        private var filterOptionData:List<FilterOptionData>? = null
        private var mSelectPosition:Int = 0
        @SuppressLint("NotifyDataSetChanged")
        fun setFilterData(filterOptionData:List<FilterOptionData>?){
            this.filterOptionData = filterOptionData
            notifyDataSetChanged()
        }
        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): FirstFilterViewHolder {
            val holder:FirstFilterViewHolder = FirstFilterViewHolder(LayoutInflater.from(context).inflate(R.layout.item_province_default,parent,false))
            holder.itemView.setOnClickListener {
                filterOptionData?.get(holder.adapterPosition)?.let {
                    onItemClick(holder.adapterPosition)
                }
            }
            return holder
        }

        private fun onItemClick(position:Int){
            if (position == mSelectPosition){
                return
            }
            notifyItemChanged(mSelectPosition)//原先
            mSelectPosition = position
            notifyItemChanged(mSelectPosition)
            filterOptionData?.get(position)?.let { onItemClick?.invoke(it) }
        }

        override fun getItemCount(): Int = this.filterOptionData?.size ?: 0

        override fun onBindViewHolder(holder: FirstFilterViewHolder, position: Int) {
            val tvContent = holder.itemView as TextView
            tvContent.text = filterOptionData?.get(position)?.selectValue
            tvContent.isSelected = position == mSelectPosition
            tvContent.paint.isFakeBoldText = position == mSelectPosition
        }

        fun setFilterOptionData(filterOptionData:List<FilterOptionData>?) {
            this.filterOptionData = filterOptionData
            notifyDataSetChanged()
        }

        class FirstFilterViewHolder(itemView: View):RecyclerView.ViewHolder(itemView)
    }

    class SecondFilterAdapter(val context:Context,private val onItemClick:((FilterOptionData)->Unit)?):RecyclerView.Adapter<SecondFilterAdapter.SecondFilterViewHolder>(){
        private var filterOptionData:List<FilterOptionData>? = null
        fun setFilterOptionData(filterOptionData:List<FilterOptionData>?){
            this.filterOptionData = filterOptionData
            notifyDataSetChanged()
        }

        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): SecondFilterViewHolder {
            val itemView = LayoutInflater.from(context).inflate(R.layout.item_city_default,parent,false)
            val holder = SecondFilterViewHolder(itemView)
            itemView.setOnClickListener {
                filterOptionData?.get(holder.adapterPosition)?.let { it1 -> onItemClick?.invoke(it1) }
            }
            return holder
        }

        override fun getItemCount(): Int = filterOptionData?.size ?: 0

        override fun onBindViewHolder(holder: SecondFilterViewHolder, position: Int) {
            val optionData = filterOptionData?.get(position)
            val tvOption:TextView = holder.itemView as TextView
            tvOption.text = optionData?.selectValue
        }

        class SecondFilterViewHolder(itemView: View):RecyclerView.ViewHolder(itemView){
            init {
                itemView.setBackgroundResource(R.drawable.selector_home_filter_label_bg)
            }
        }
    }
}