package com.alpha.lagouapk.ui.home.v2.fragment

import android.annotation.SuppressLint
import android.content.Context
import android.graphics.Color
import android.graphics.drawable.GradientDrawable
import android.os.Bundle
import android.os.Message
import android.view.View
import android.widget.FrameLayout
import android.widget.TextView
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.HomeActivityConfigBean
import com.alpha.lagouapk.bean.HomeOverseaReqBean
import com.alpha.lagouapk.bean.HomePositionParams
import com.alpha.lagouapk.bean.LoadMoreEventBean
import com.alpha.lagouapk.bean.OperationBean
import com.alpha.lagouapk.bean.PositionInfo
import com.alpha.lagouapk.delivery.model.DeliveryModel
import com.alpha.lagouapk.manager.PositionLabelManager
import com.alpha.lagouapk.manager.PositionLabelManager.fetchPositionLabel
import com.alpha.lagouapk.manager.PositionLabelManager.fetchPositionsLabel
import com.alpha.lagouapk.observer.EventTags
import com.alpha.lagouapk.tools.config.MainConfig
import com.alpha.lagouapk.ui.home.HomeContract.FView
import com.alpha.lagouapk.ui.home.HomeFragmentPresenter
import com.alpha.lagouapk.ui.home.v2.HomeOverseaAdapter
import com.alpha.lagouapk.ui.home.v2.OffsetLinearLayoutManager
import com.alpha.lagouapk.ui.home.v2.inter.OnScrollListener
import com.alpha.lagouapk.ui.home.v2.manager.analytic.HomePositionAnalyticManager
import com.alpha.lagouapk.ui.home.v2.manager.business.HomePositionManager
import com.alpha.lagouapk.ui.home.v2.refresh.HomeRefresh
import com.alpha.lagouapk.ui.position.PositionDetailActivity
import com.alpha.lagouapk.widget.behavior.HomeActivityCardManager
import com.alpha.lagouapk.widget.decoration.DividerItemDecoration
import com.common.widget.WifiView
import com.lagou.baselib.BaseFragment
import com.lagou.commonlibs.event.Event
import com.lagou.commonlibs.event.OkBus
import com.lagou.commonlibs.utils.BaseUtils
import com.lagou.commonlibs.utils.ListUtil
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.view.recyclerview.DefaultLoadView
import com.lagou.commonlibs.view.recyclerview.LmRecyclerView
import com.lagou.component.ui.refreshLayout.NewPullToRefreshLayout
import com.lagou.socketchannel.util.NetUtil


/**
 * 出海
 */
class HomeOverseaFragment :BaseFragment(), HomeRefresh.OnRefreshListener, FView{
    private lateinit var mPullToRefreshLayout:NewPullToRefreshLayout
    private lateinit var mRecyclerView:LmRecyclerView
    private lateinit var mTvRefreshTip: TextView
    private lateinit var mWifiView:WifiView
    private var mHomeRefresh:HomeRefresh? = null
    private lateinit var mPresenter: HomeFragmentPresenter
    private lateinit var  mLinearLayoutManager:OffsetLinearLayoutManager
    private lateinit var mRootView:FrameLayout
    private var mPositionAdapter: HomeOverseaAdapter? = null
    private var mPositionList = mutableListOf<PositionInfo>()
    private var mExpectId:Int = 0
    private var isRefresh:Boolean = false
    private var hasMore:Boolean = false
    private var mOnScrollListener: OnScrollListener? = null
    private var mLoadMoreListener:PositionDetailActivity.LoadMoreListener? = null
    private lateinit var mHomePositionManager:HomePositionManager
    private var mRequestParams:HomeOverseaReqBean? = null
    companion object {
        const val KEY_EXPECT_JOB_ID = "expectJobId"
        @JvmStatic
        fun newInstance(expectId:Int): HomeOverseaFragment {
            val bundle = Bundle()
            bundle.putInt(KEY_EXPECT_JOB_ID,expectId)
            val fragment = HomeOverseaFragment()
            fragment.arguments = bundle
            return fragment
        }
    }

    /**
     * 投递成功事件
     */
    @SuppressLint("NotifyDataSetChanged")
    private val deliverSuccessEvent = Event { msg: Message ->
            if (msg.obj is DeliveryModel) {
                fetchPositionLabel((msg.obj as DeliveryModel).positionId, PositionLabelManager.POSITION_SCENE_HOME) { isSuccess: Boolean ->
                    if (isSuccess) {
                        mPositionAdapter?.notifyDataSetChanged()
                    }
                    null
                }
            }
        }

    private val mLoadMoreEvent = Event { msg: Message? ->
        if (msg == null) {
            return@Event
        }
        if (msg.obj is LoadMoreEventBean) {
            mLoadMoreListener = (msg.obj as LoadMoreEventBean).loadMoreListener
            if (!mHomePositionManager.isFromHomePage((msg.obj as LoadMoreEventBean).source)) {
                return@Event
            }
            if ((msg.obj as LoadMoreEventBean).extentParam == null) {
                return@Event
            }
            val expectJobId = (msg.obj as LoadMoreEventBean).extentParam[LoadMoreEventBean.KEY_EXPECT_ID]
            if (expectJobId is Int && expectJobId == mExpectId) {
                loadMore()
            }
        }
    }

    override fun onAttach(context: Context) {
        super.onAttach(context)
        mOnScrollListener = context as? OnScrollListener
        mExpectId = arguments?.getInt(KEY_EXPECT_JOB_ID) ?: 0
    }

    override fun getLayoutId(): Int = R.layout.fragment_home_oversea_main

    override fun init() {
        mPresenter = HomeFragmentPresenter()
        mPresenter.attachView(this)
        mHomePositionManager = HomePositionManager()
        this.initView()
        this.initListener()
        this.registerEvent()
        initRequestParams()
        refreshData()
        setTheme()
    }

    private fun setTheme() {
        val configBean:HomeActivityConfigBean? = HomeActivityCardManager.getInstance().getOverseaConfig(mExpectId)
        val refreshLayoutBgColor = if (BaseUtils.checkColorStrIsValid(configBean?.activityStartColor)) configBean?.activityStartColor else "#ffffff"
        val rootStartColor = if (BaseUtils.checkColorStrIsValid(configBean?.activityStartColor)) configBean?.activityStartColor else "#ECFFFF"
        val rootEndColor = if (BaseUtils.checkColorStrIsValid(configBean?.activityEndColor)) configBean?.activityEndColor else "#DDEEFF"
        updateTheme(refreshLayoutBgColor)
        val rootBgDrawable = GradientDrawable().apply {
            shape = GradientDrawable.RECTANGLE
            orientation = GradientDrawable.Orientation.TOP_BOTTOM
            colors = intArrayOf(Color.parseColor(rootStartColor), Color.parseColor(rootEndColor))
        }
        mRootView.background = rootBgDrawable
    }

    private fun initView() {
        mPullToRefreshLayout = findViewById(R.id.pull_to_refresh)
        mRecyclerView = findViewById(R.id.rv_home_oversea_position)
        mTvRefreshTip = findViewById(R.id.tv_refresh_tip)
        mWifiView = findViewById(R.id.wifi_view)
        mRootView = findViewById(R.id.root_oversea)
        initHomeRefresh()
        mLinearLayoutManager = object : OffsetLinearLayoutManager(mContext) {
            override fun onLayoutChildren(recycler: RecyclerView.Recycler, state: RecyclerView.State) {
                try {
                    super.onLayoutChildren(recycler, state)
                } catch (e: IndexOutOfBoundsException) {
                }
            }

            override fun supportsPredictiveItemAnimations(): Boolean {
                return false
            }
        }
        mPositionAdapter = HomeOverseaAdapter(mContext, mPositionList,mExpectId,mHomePositionManager.tabType2JdSource(getSource())) {
            var condition:HashMap<String,List<String>> = HashMap()
            for ((key, value) in it) {
               if(key.isNullOrEmpty() or value.isNullOrEmpty()){
                   continue
               }
                condition[key!!] = value!!
            }
            mRequestParams?.condition = condition
            requestData(true)
        }
        mRecyclerView.apply {
            setPrefetchOffset(5)
            layoutManager = mLinearLayoutManager
            setInitLoading(false)
            makeLabel()
            addItemDecoration(DividerItemDecoration(context, DividerItemDecoration.HORIZONTAL_LIST, ResourceUtils.getDimenSize(R.dimen.dp_10), ResourceUtils.getColor(R.color.transparent)))
            adapter = mPositionAdapter
        }
        val loadView = mRecyclerView.loadMoreView
        if (loadView is DefaultLoadView) {
            loadView.setNoMoreText(resources.getString(R.string.string_no_position))
        }
    }
    private fun initListener() {
        mRecyclerView.addOnScrollListener(object : RecyclerView.OnScrollListener() {
            override fun onScrollStateChanged(recyclerView: RecyclerView, state: Int) {
                super.onScrollStateChanged(recyclerView, state)
            }
            override fun onScrolled(recyclerView: RecyclerView, dx: Int, dy: Int) {
                super.onScrolled(recyclerView, dx, dy)
                mOnScrollListener?.onScroll(dx, dy, recyclerView.computeVerticalScrollOffset(), mLinearLayoutManager.headViewHeight)
            }
        })
        mWifiView.setReLoadListener {
            onRefresh()
        }
        mRecyclerView.setOnLoadMoreListener {
            if (mPullToRefreshLayout.isRefreshing) {
                mRecyclerView.setLoadMoreState(LmRecyclerView.HIDDEN)
            }
            loadMore()
        }

    }

    private fun registerEvent() {
        OkBus.getInstance().register(EventTags.HOME_POSITION_LOAD_MORE, mLoadMoreEvent)
        OkBus.getInstance().register(EventTags.JD_POSITION_DELIVER_SUCCESS_NOTIFY, deliverSuccessEvent)
    }
    private fun unRegisterEvent() {
        OkBus.getInstance().unRegister(mLoadMoreEvent)
        OkBus.getInstance().unRegister(deliverSuccessEvent)
        mLoadMoreListener = null
    }


    private fun initHomeRefresh() {
        mHomeRefresh = HomeRefresh(context, mPullToRefreshLayout, mTvRefreshTip)
        mHomeRefresh?.setListener(this)
        val operation = HomeActivityCardManager.getInstance().operation
        if (operation != null && !ListUtil.isEmpty<OperationBean>(operation.adVos)) {
            val operationBean = operation.adVos[0]
            if (operationBean != null && BaseUtils.checkColorStrIsValid(operationBean.color)) {
                mHomeRefresh?.setTheme(operationBean.color)
            }
        }
    }

    override fun onRefresh() {
        if (isRefresh) {
            return
        }
        HomePositionAnalyticManager.getInstance().reset()
        scrollToTop()
        requestData(true)
    }

    private fun loadMore(){
        if (isRefresh || !hasMore) {
            return
        }
        requestData(false)
    }
    /**
     * 列表滚动到顶部
     */
    private fun scrollToTop() {
        mRecyclerView.post {
            mRecyclerView.scrollTo(0, 0)
            mLinearLayoutManager.scrollToPositionWithOffset(0, 0)
        }
    }

    override fun onRefreshViewReset() {

    }

    fun updateTheme(themeColor: String?) {
        mPositionAdapter?.setNotifyHead(true)
        mPositionAdapter?.setHeaderData(if (HomeActivityCardManager.getInstance().isHasOverseaAd(mExpectId)) Any() else null)
        mHomeRefresh?.setTheme(themeColor)
    }

    /**
     * 刷新请求数据
     */
    fun refreshData() {
        if (!mPullToRefreshLayout.isRefreshing) {
            mPullToRefreshLayout.isRefreshing = true
        } else {
            requestData(true)
        }
    }

    /**
     * 请求职位数据
     */
    private fun requestData(isRefresh:Boolean){
        this.isRefresh = isRefresh
        mPresenter.getNewPositionInformation(null, if (isRefresh) MainConfig.TYPE_REFRESH else MainConfig.TYPE_NORMAL,
            getSource(), mRequestParams, null)
    }

    private fun initRequestParams(){
        if (mRequestParams == null){
            mRequestParams = HomeOverseaReqBean().apply {
                activityCode = HomeActivityCardManager.getInstance().getOverseaConfig(mExpectId)?.activityCode
                expectJobId = mExpectId
            }
        }
    }

    /**
     * 提示请求数据的数量
     */
    private fun checkRefreshFinish() {
        if (!isRefresh) {
            return
        }
        mHomeRefresh?.setTip("推荐职位已更新")
        mPullToRefreshLayout.isRefreshing = false
    }

    @SuppressLint("NotifyDataSetChanged")
    fun notifyDataSetChanged() {
        if (mRecyclerView.isComputingLayout) {
            return
        }
        mPositionAdapter?.setNotifyHead(false)
        mPositionAdapter?.showEmptyView(mPositionList.isEmpty())
        mPositionAdapter?.notifyDataSetChanged()
    }

    override fun onDestroyView() {
        super.onDestroyView()
        mPresenter.detachView()
        unRegisterEvent()
    }

    override fun onDestroy() {
        super.onDestroy()
        HomePositionAnalyticManager.getInstance().reset()
    }
    /**
     * 请求职位成功回调
     */
    override fun onGetPositionSuccess(result: MutableList<PositionInfo>?, params: HomePositionParams?) {
        mWifiView.visibility = View.GONE
        mPullToRefreshLayout.visibility = View.VISIBLE
        hasMore = (result?.size ?: 0) >= MainConfig.SearchJobNum
        if (isRefresh) {
            mPositionList.clear()
            //为了解决这个问题，加了下面一行，java.lang.IndexOutOfBoundsException: Inconsistency detected. Invalid item position
            notifyDataSetChanged()
            mOnScrollListener?.onScroll(0, 0, 0, mLinearLayoutManager.headViewHeight)
        }
        mRecyclerView.completeOnSuccess(hasMore)
        if (result != null) {
            mPositionList.addAll(result)
            notifyDataSetChanged()
            val positionIds: ArrayList<Long>? = HomePositionManager.getPositionIds(result) as ArrayList<Long>?
            fetchPositionsLabel(positionIds, PositionLabelManager.POSITION_SCENE_HOME) { isSuccess: Boolean ->
                if (isSuccess) {
                    notifyDataSetChanged()
                }
               null
            }
            mLoadMoreListener?.onLoadOk(positionIds, HomePositionManager.getPositionDetailLoadingBeans(result))
        }
        if (mPositionList.isEmpty()) {
            if (!NetUtil.isNetworkConnected(mContext)) {
                mWifiView.visibility = View.VISIBLE
                mPullToRefreshLayout.visibility = View.GONE
            }
            mRecyclerView.setLoadMoreState(LmRecyclerView.HIDDEN)
        }
        checkRefreshFinish()
        isRefresh = false
    }
    private fun getSource(): Int {
        return MainConfig.HOME_TAB_TYPE_OVERSEA
    }
}