package com.alpha.lagouapk.ui.resume.edit

import android.annotation.SuppressLint
import android.content.Context
import android.os.CountDownTimer
import android.text.InputFilter
import android.text.InputType
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.ApiService
import com.alpha.lagouapk.R
import com.alpha.lagouapk.bean.EmailVerifyReq
import com.alpha.lagouapk.tools.DensityUtil
import com.common.afterTextChanged
import com.common.inter.OnItemClickListener
import com.common.utils.KeyboardUtils
import com.lagou.annotation.aspect.SingleClick
import com.lagou.baselib.BaseActivity
import com.lagou.baselib.net.httpnetback.BaseCallback
import com.lagou.commonlibs.utils.*
import com.lagou.commonlibs.view.filter.NotChineseFilter
import com.lagou.socketchannel.http.HttpRequest
import com.lagou.socketchannel.http.HttpResponse
import com.lxj.xpopup.core.BottomPopupView
import kotlinx.android.synthetic.main.auto_itm.view.*
import kotlinx.android.synthetic.main.dialog_eidt_resume_email.view.*

class EditResumeEmailDialog(val mContext: Context, val email:String?):BottomPopupView(mContext) {
    private var verifyCodeCountdown:VerifyCodeCountdown? = null
    private var emailSuggestAdapter:EmailSuggestAdapter? = null
    override fun getImplLayoutId() = R.layout.dialog_eidt_resume_email
    override fun onCreate() {
        super.onCreate()
        initView()
        initListener()
    }

    private fun initView() {
        verifyCodeCountdown = VerifyCodeCountdown(60 * 1000, 1000)
        mEditEmail.apply {
            inputType = InputType.TYPE_TEXT_VARIATION_EMAIL_ADDRESS
            isFocusable = true
            requestFocus()
            filters = arrayOf<InputFilter>(NotChineseFilter())
        }
        emailSuggestAdapter = EmailSuggestAdapter(mContext)
        mRecyclerView.apply {
            setHasFixedSize(true)
            layoutManager = LinearLayoutManager(mContext)
            addItemDecoration(DividerItemDecoration(context, DividerItemDecoration.VERTICAL))
            isNestedScrollingEnabled = false
            adapter = emailSuggestAdapter
        }
    }


    private fun initListener() {
        mEditEmail.setOnFocusChangeListener { _, hasFocus ->
            val bgColorId = if (hasFocus) R.color.color_00b38a else R.color.color_e8e9eb
            setLineBackgroundColor(mLineEmail,bgColorId)
        }
        mEditEmailCode.setOnFocusChangeListener { _, hasFocus ->
            val bgColorId = if (hasFocus) R.color.color_00b38a else R.color.color_e8e9eb
            setLineBackgroundColor(mLineEmailCode,bgColorId)
        }
        mEditEmail.afterTextChanged {
            mTvGetEmailCode.isEnabled = it.isNullOrEmpty().not()
            mTvGetEmailCode.setTextColor(ResourceUtils.getColor(if (mTvGetEmailCode.isEnabled) R.color.color_00b38a else R.color.color_cccccc))
            emailSuggestAdapter?.setInput(it?.toString())
        }
        emailSuggestAdapter!!.setItemClickListener(object : OnItemClickListener<String>{
            override fun onItemClickListener(itemView: View, position: Int, email: String?) {
                mEditEmail.setText(email)
                mEditEmail.setSelection(email?.length ?: 0)
                emailSuggestAdapter?.setInput(null)
            }
        })
        mRecyclerView.addOnScrollListener(object : RecyclerView.OnScrollListener() {
            override fun onScrollStateChanged(recyclerView: RecyclerView, newState: Int) {
                super.onScrollStateChanged(recyclerView, newState)
                if (newState == RecyclerView.SCROLL_STATE_DRAGGING) { //正在滚动
                    InputMethodUtil.hideSystemKeyBoard(context, mEditEmail)
                }
            }
        })
        mTvGetEmailCode.setOnClickListener { getVerCode() }
        ivClose.setOnClickListener { dismiss() }
        tvOk.setOnClickListener {
            confirm()
        }
    }

    /**
     * 确认
     */
    private fun confirm(){
        if (checkDataIsValid().not()){
            return
        }
        ApiService.api.verfiyEmailCode(mEditEmail.text?.toString(),mEditEmailCode.text?.toString(),EmailVerifyReq.BusinessType.ONLINE_RESUME_EMAIL_UPDATE)
            .enqueue(object:BaseCallback<Any?>(){
                override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<Any?>?) {
                    if (mContext is BaseActivity && !mContext.isActivityDestroyed){
                        onCallback?.onEmailInfoCallback(mEditEmail.text?.toString())
                        dismiss()
                    }
                }

            })
    }

    /**
     * 校验邮箱和验证码
     */
    private fun checkDataIsValid(): Boolean {
        val checkEmail = mEditEmail.text?.toString()
        val checkEmailCode = mEditEmailCode.text?.toString()
        if (checkEmail.isNullOrEmpty()) {
            ToastUtil.showCenter(mContext, ResourceUtils.getString(R.string.string_mail_tips))
            setLineBackgroundColor(mLineEmail,R.color.color_ff7452)
            return false
        }
        if (!RegexUtil.isEmail(checkEmail)) {
            ToastUtil.showCenter(mContext, ResourceUtils.getString(R.string.toast_email_error))
            setLineBackgroundColor(mLineEmail,R.color.color_ff7452)
            return false
        }
        setLineBackgroundColor(mLineEmail,R.color.color_e8e9eb)
        if (checkEmailCode.isNullOrEmpty()){
            ToastUtil.showCenter(mContext, ResourceUtils.getString(R.string.email_input_verify_code))
            setLineBackgroundColor(mLineEmailCode,R.color.color_ff7452)
            return false
        }
        return true
    }

    private fun setLineBackgroundColor(lineView: View, colorResId:Int){
        lineView.setBackgroundColor(ResourceUtils.getColor(colorResId))
    }

    /**
     * 点击获取验证码
     */
    @SingleClick
    private fun getVerCode(){
        val checkEmail = mEditEmail.text?.toString()
        if (checkEmail.isNullOrEmpty()) {
            ToastUtil.showCenter(mContext, ResourceUtils.getString(R.string.string_mail_tips))
            setLineBackgroundColor(mLineEmail,R.color.color_ff7452)
            return
        }
        if (!RegexUtil.isEmail(checkEmail)) {
            ToastUtil.showCenter(mContext, ResourceUtils.getString(R.string.toast_email_error))
            setLineBackgroundColor(mLineEmail,R.color.color_ff7452)
            return
        }
        if (TextUtils.equals(email,checkEmail)){
            ToastUtil.showCenter(mContext,ResourceUtils.getString(R.string.email_not_changed))
            setLineBackgroundColor(mLineEmail,R.color.color_ff7452)
            return
        }
        emailSuggestAdapter?.setInput(null)
        setLineBackgroundColor(mLineEmail,R.color.color_e8e9eb)
        KeyboardUtils.hideSoftInput(mEditEmail)
        val emailVerifyReq = EmailVerifyReq()
        emailVerifyReq.businessType = EmailVerifyReq.BusinessType.ONLINE_RESUME_EMAIL_UPDATE
        emailVerifyReq.email = mEditEmail.text?.toString()
        ApiService.api.fetchResumeEmailCode(emailVerifyReq).protect()
            .enqueue(object : BaseCallback<Any?>() {
                override fun onSuccess(request: HttpRequest<*>?, response: HttpResponse<Any?>?) {
                   if (mContext is BaseActivity){
                       if (mContext.isActivityDestroyed){
                           return
                       }
                       ToastUtil.showCenter(mContext, ResourceUtils.getString(R.string.email_verify_send_success))
                       verifyCodeCountdown?.start()
                   }
                }
            })
    }

    /**
     * 获取验证码倒计时
     */
    private inner class VerifyCodeCountdown(millisInFuture: Long, countDownInterval: Long) : CountDownTimer(millisInFuture, countDownInterval) {
        override fun onFinish() {
            mTvGetEmailCode.apply {
                text = ResourceUtils.getString(R.string.verify_code_resend)
                isEnabled = true
                alpha = 1f
            }
        }

        @SuppressLint("SetTextI18n")
        override fun onTick(millisUntilFinished: Long) {
            mTvGetEmailCode.apply {
                text = "已发送 " + millisUntilFinished / 1000 + "s"
                isEnabled = false
                alpha = 0.3f
            }
        }
    }

    override fun onDismiss() {
        super.onDismiss()
        verifyCodeCountdown?.cancel()
    }
    override fun getMaxHeight(): Int {
        return DeviceUtils.getScreenHeight() - DensityUtil.dip2px(mContext, 150f)
    }

    override fun getPopupHeight(): Int {
        return DeviceUtils.getScreenHeight() - DensityUtil.dip2px(mContext, 150f)
    }


    class EmailSuggestAdapter(val context:Context,var inputContent:String?=null): RecyclerView.Adapter<EmailSuggestAdapter.EmailSuggestViewHolder>() {
        private lateinit var recyclerView :RecyclerView
        private var data:Array<String> = ResourceUtils.getStringArray(R.array.email_format)
        private var _data:Array<String>?
        private var _input:String
        init {
            this._input = inputContent?.substringBefore("@") ?: ""
            _data = if (this._input.isEmpty()) null else data
        }
        fun setInput(input:String?){
            this._input = input?.substringBefore("@") ?: ""
            _data = if (this._input.isEmpty()) null else data
            notifyDataSetChanged()
        }

        override fun onAttachedToRecyclerView(recyclerView: RecyclerView) {
            super.onAttachedToRecyclerView(recyclerView)
            this.recyclerView = recyclerView
        }
        override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): EmailSuggestViewHolder {
            val view = LayoutInflater.from(context).inflate(R.layout.auto_itm, parent, false)
            view.setOnClickListener {
                val position = recyclerView.getChildAdapterPosition(view)
                onItemClickListener?.onItemClickListener(view,position,_input.plus(_data?.get(position)))
            }
            return EmailSuggestViewHolder(view)
        }

        override fun onBindViewHolder(holder: EmailSuggestViewHolder, position: Int) {
            holder.tvItemView.text = _input.plus(_data?.get(position))
            StringUtil.highlightKeyWord(holder.tvItemView,inputContent)
        }

        override fun getItemCount(): Int = _data?.size ?: 0
        private var onItemClickListener:OnItemClickListener<String>? = null
        fun setItemClickListener(itemClickListener:OnItemClickListener<String>){
            this.onItemClickListener = itemClickListener
        }
        class EmailSuggestViewHolder(itemView:View): RecyclerView.ViewHolder(itemView) {
            val tvItemView: TextView = itemView.tv_auto_item
        }
    }
    private var onCallback:OnCallback? = null
    fun setOnCallback(onCallback:OnCallback?){
        this.onCallback = onCallback
    }
    interface OnCallback{
        fun onEmailInfoCallback(email:String?)
    }
}