package com.lagou.lagouee.bean.search

import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_BROWSE
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_EDUCATION
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_EXPERIENCE
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_FAMOUS
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_GAP_PERIOD
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_GENDER
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_GRADUATE
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_INDUSTRY
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_JOB_HOPPING
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_JOB_HUNTING
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_MAJOR
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_OUTSIDE
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_SALARY
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.FILTER_OPTION_SCHOOL
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.MORE_FILTER_TITLE
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.SLIDE_FILTER_OPTION_AGE
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.SLIDE_FILTER_OPTION_SALARY
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_JOB_HOPPING
import com.lagou.lagouee.ui.search.BSearchHelper

/**
 * Time：2024/4/26 17:19:55
 * Author：wangjunwei
 * Description：搜索基础筛选项
 * @param type 什么类型
 * @param typeTxt 类型中文文本表示 （现主要用于付费筛选类别匹配）
 * @param isTitle 是否是标题
 * @param location 位置 left middle right
 * @param isNobleStyle 高贵的金色风格
 * @param isSelected 是否被选中
 */
open class BaseSearchFilterOptionData(
    open val type: String,
    open val typeTxt: String,
    isTitle: Boolean,
    open val location: String?,
    open var isNobleStyle: Boolean = false,
    open var isSelected: Boolean
) {

    /**
     * 1 通用标题类型
     */
    fun isCommonTitleType(): Boolean {
        return BSearchHelper.titleDataCloseMap.keys.filter {
            it != MORE_FILTER_TITLE
        }.contains(type) ||
                BSearchHelper.titleDataExpandSuffixMap.keys.filter {
                    it != MORE_FILTER_TITLE
                }.contains(type)

    }

    /**
     * 2 通用选项
     */
    fun isCommonOption(): Boolean {

        return FILTER_OPTION_EXPERIENCE == type
                || FILTER_OPTION_EDUCATION == type
                || FILTER_OPTION_SCHOOL == type
                || FILTER_OPTION_GENDER == type
                || FILTER_OPTION_JOB_HUNTING == type
                || FILTER_OPTION_GAP_PERIOD == type
                || FILTER_OPTION_FAMOUS == type
                || FILTER_OPTION_BROWSE == type

    }


    /**
     * 2.1 薪资选项
     */
    fun isSalaryOption(): Boolean {
        return FILTER_OPTION_SALARY == type
    }

    /**
     * 3.1 滑块年龄选项
     */
    fun isSlideAgeOption(): Boolean {
        return SLIDE_FILTER_OPTION_AGE == type
    }

    /**
     * 3.2 滑块薪资选项
     */
    fun isSlideSalaryOption(): Boolean {
        return SLIDE_FILTER_OPTION_SALARY == type
    }

    /**
     * 4 毕业时间选项
     */
    fun isGraduateOption(): Boolean {
        return FILTER_OPTION_GRADUATE == type
    }

    /**
     * 5 专业选项
     */
    fun isMajorOption(): Boolean {
        return FILTER_OPTION_MAJOR == type
    }


    /**
     * 6 所在行业
     */
    fun isIndustryOption(): Boolean {
        return FILTER_OPTION_INDUSTRY == type
    }

    /**
     * 7 流式选项
     */
    fun isFlowOption(): Boolean {
        return FILTER_OPTION_OUTSIDE == type
                || FILTER_OPTION_JOB_HOPPING == type
    }

    /**
     * 8 更多标题类型
     */
    fun isMoreTitleType(): Boolean {
        return MORE_FILTER_TITLE == type
    }

    /**
     * 左侧
     */
    fun isLocationLeft(): Boolean {
        return BSearchFilterOptionType.LOCATION_LEFT == location
    }

    /**
     * 中间
     */
    fun isLocationMiddle(): Boolean {
        return BSearchFilterOptionType.LOCATION_MIDDLE == location
    }

    /**
     * 右侧
     */
    fun isLocationRight(): Boolean {
        return BSearchFilterOptionType.LOCATION_RIGHT == location
    }

}