package com.lagou.lagouee.ui.adapter

import android.content.Context
import android.text.TextUtils
import android.view.LayoutInflater
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.common.adapter.listener.OnItemClick
import com.lagou.commonlibs.utils.ListUtil
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.utils.StringUtil
import com.lagou.lagouee.bean.jsonbean.search.ShowV3SearchRes
import com.lagou.lagouee.bean.search.BSearchFilterOptionType
import com.lagou.lagouee.bean.search.BaseSearchFilterOptionData
import com.lagou.lagouee.bean.search.DefaultSearchFilterOptionData
import com.lagou.lagouee.bean.search.FlowSearchFilterOptionData
import com.lagou.lagouee.bean.search.GraduateSpinnerSearchFilterOptionData
import com.lagou.lagouee.bean.search.SalarySearchFilterOptionData
import com.lagou.lagouee.bean.search.SearchConstants
import com.lagou.lagouee.bean.search.SearchFilterData
import com.lagou.lagouee.bean.search.SlideSearchFilterOptionData
import com.lagou.lagouee.bean.search.SpinnerSearchFilterOptionData
import com.lagou.lagouee.bean.search.TitleSearchFilterOptionData
import com.lagou.lagouee.manager.BRequestConfigManager
import com.lagou.lagouee.ui.search.BSearchHelper
import com.lagou.lagouee.ui.search.SearchActivity

/**
 * Time：2024/5/29 11:12:34
 * Author：wangjunwei
 * Description：提取B端搜索页更多筛选项基类
 */
abstract class BaseFilterMoreAdapter(context: Context) : FilterAdapter() {


    /**
     * 选中的选项bean
     */
    protected var searchFilterData: SearchFilterData? = null

    protected val mLayoutInflater: LayoutInflater

    /**
     * 适配器显示使用数据集（展开和关闭数据不一样）
     */
    protected val adapterFilterDataList = mutableListOf<BaseSearchFilterOptionData>()

    /**
     * 完整的筛选项list（收起&展开之后的）,用于记录完整的选项的选中状态
     */
    protected val completeAdapterFilterDataList = mutableListOf<BaseSearchFilterOptionData>()

    /**
     * 适配器使用到的数据源，支持变更顺序
     */
    protected val adapterFilterCloseDataList: MutableList<BaseSearchFilterOptionData>
    protected val adapterFilterExpandSuffixDataList: MutableList<BaseSearchFilterOptionData>


    internal var onItemClick: OnItemClick<BaseSearchFilterOptionData>? = null

    fun setOnItemClickListener(onItemClick: OnItemClick<BaseSearchFilterOptionData>?) {
        this.onItemClick = onItemClick
    }

    init {
        mLayoutInflater = LayoutInflater.from(context)

        adapterFilterCloseDataList = BSearchHelper.getFilterOptionDataCloseList()
        adapterFilterExpandSuffixDataList = BSearchHelper.getFilterOptionDataExpandSuffixList()
        adapterFilterDataList.addAll(adapterFilterCloseDataList)

        completeAdapterFilterDataList.addAll(adapterFilterCloseDataList)
        completeAdapterFilterDataList.addAll(adapterFilterExpandSuffixDataList)

        preprocessingOptions()
    }

    /**
     * 基础数据预处理
     */
    abstract fun preprocessingOptions()

    /**
     * 把选中的数据映射到页面上
     */
    fun setSearchFilter(searchFilterData: SearchFilterData?) {
        this.searchFilterData = searchFilterData
        //1 没有任何选中数据的情况，确切的说是初始化的情况下
        if (searchFilterData == null) {
            resetAll()
            return
        }
        //2 把选中数据逐个字段映射到列表中
        fillSearchData(searchFilterData, adapterFilterDataList)
        fillSearchData(searchFilterData, adapterFilterExpandSuffixDataList)

        notifyDataSetChanged()
    }

    /**
     * 把筛选项数据填充到具体的筛选项上，历史搜索等，保持两者一致性
     */
    private fun fillSearchData(
        searchFilterData: SearchFilterData,
        filterDataList: MutableList<BaseSearchFilterOptionData>
    ) {
        val searchEducation = mutableListOf<String>()
        //职位卡片中的本科，映射成本科 (最高学历)
        searchFilterData.education?.forEach {
            if (!TextUtils.isEmpty(it)) {
                if (TextUtils.equals("本科", it)) {
                    searchEducation.add("本科 (最高学历)")
                } else {
                    searchEducation.add(it)
                }
            }
        }
        filterDataList.forEachIndexed { index, fileOptionData ->
            when (fileOptionData.type) {
                BSearchFilterOptionType.FILTER_OPTION_EXPERIENCE,
                BSearchFilterOptionType.FILTER_OPTION_EDUCATION,
                BSearchFilterOptionType.FILTER_OPTION_SCHOOL,
                BSearchFilterOptionType.FILTER_OPTION_GENDER,
                BSearchFilterOptionType.FILTER_OPTION_JOB_HUNTING,
                BSearchFilterOptionType.FILTER_OPTION_GAP_PERIOD,
                BSearchFilterOptionType.FILTER_OPTION_FAMOUS,
                BSearchFilterOptionType.FILTER_OPTION_BROWSE
                -> {
                    fileOptionData as DefaultSearchFilterOptionData
                    //一个都没选中，默认选中不限
                    if (fileOptionData.type == BSearchFilterOptionType.FILTER_OPTION_EXPERIENCE) {
                        if (TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), fileOptionData.content)
                            && ListUtil.isEmpty(searchFilterData.workYear)) {
                            fileOptionData.isSelected = true
                        } else {
                            fileOptionData.isSelected = !ListUtil.isEmpty(searchFilterData.workYear)
                                    && searchFilterData.workYear?.indexOf(fileOptionData.content) != -1
                        }
                    } else if (fileOptionData.type == BSearchFilterOptionType.FILTER_OPTION_EDUCATION) {
                        if (TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), fileOptionData.content)
                            && ListUtil.isEmpty(searchFilterData.education)) {
                            fileOptionData.isSelected = true
                        } else {
                            fileOptionData.isSelected =
                                !ListUtil.isEmpty(searchFilterData.education) &&
                                        searchEducation.contains(fileOptionData.content) == true
                        }
                    } else if (fileOptionData.type == BSearchFilterOptionType.FILTER_OPTION_SCHOOL) {
                        if (TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), fileOptionData.content)
                            && ListUtil.isEmpty(searchFilterData.schoolType)) {
                            fileOptionData.isSelected = true
                        } else {
                            fileOptionData.isSelected =
                                !ListUtil.isEmpty(searchFilterData.schoolType) &&
                                        searchFilterData.schoolType?.indexOf(fileOptionData.content) != -1
                        }
                    } else if (fileOptionData.type == BSearchFilterOptionType.FILTER_OPTION_GENDER) {
                        if (TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), fileOptionData.content)
                            && ListUtil.isEmpty(searchFilterData.gender)) {
                            fileOptionData.isSelected = true
                        } else {
                            fileOptionData.isSelected =
                                !ListUtil.isEmpty(searchFilterData.gender) &&
                                        searchFilterData.gender?.indexOf(fileOptionData.content) != -1
                        }
                    } else if (fileOptionData.type == BSearchFilterOptionType.FILTER_OPTION_JOB_HUNTING) {
                        if (TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), fileOptionData.content)
                            && ListUtil.isEmpty(searchFilterData.jobHuntingStatus)) {
                            fileOptionData.isSelected = true
                        } else {
                            fileOptionData.isSelected =
                                !ListUtil.isEmpty(searchFilterData.jobHuntingStatus) &&
                                        searchFilterData.jobHuntingStatus?.indexOf(fileOptionData.content) != -1
                        }
                    } else if (fileOptionData.type == BSearchFilterOptionType.FILTER_OPTION_GAP_PERIOD) {
                        if (TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), fileOptionData.content)
                            && TextUtils.isEmpty(searchFilterData.period)) {
                            fileOptionData.isSelected = true
                        } else {
                            fileOptionData.isSelected =
                                searchFilterData.period == fileOptionData.content
                        }
                    } else if (fileOptionData.type == BSearchFilterOptionType.FILTER_OPTION_FAMOUS) {
                        if (TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), fileOptionData.content)
                            && ListUtil.isEmpty(searchFilterData.company)) {
                            fileOptionData.isSelected = true
                        } else {
                            fileOptionData.isSelected =
                                !ListUtil.isEmpty(searchFilterData.company) &&
                                        searchFilterData.company?.indexOf(fileOptionData.content) != -1
                        }
                    } else if (fileOptionData.type == BSearchFilterOptionType.FILTER_OPTION_BROWSE) {
                        if (TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), fileOptionData.content)
                            && ListUtil.isEmpty(searchFilterData.preference)) {
                            fileOptionData.isSelected = true
                        } else {
                            fileOptionData.isSelected =
                                !ListUtil.isEmpty(searchFilterData.preference) &&
                                        searchFilterData.preference?.indexOf(fileOptionData.content) != -1
                        }
                    }
                }

                BSearchFilterOptionType.SLIDE_FILTER_OPTION_AGE,
                BSearchFilterOptionType.SLIDE_FILTER_OPTION_SALARY -> {
                    fileOptionData as SlideSearchFilterOptionData
                    if (fileOptionData.type == BSearchFilterOptionType.SLIDE_FILTER_OPTION_AGE) {
                        fileOptionData.minValue = searchFilterData.ageLower
                        fileOptionData.maxValue = searchFilterData.ageUpper
                    } else {
                        fileOptionData.minValue = searchFilterData.salaryLower
                        fileOptionData.maxValue = searchFilterData.salaryUpper
                    }
                }

                BSearchFilterOptionType.FILTER_OPTION_SALARY -> {
                    fileOptionData as SalarySearchFilterOptionData
                    fileOptionData.isSelected =
                        TextUtils.equals(fileOptionData.content, searchFilterData.salarySelectTxt)
                }

                BSearchFilterOptionType.FILTER_OPTION_GRADUATE -> {
                    fileOptionData as GraduateSpinnerSearchFilterOptionData
                    fileOptionData.apply {
                        txt = searchFilterData.graduateTime
                        if (TextUtils.equals("及以前", searchFilterData.graduateAgoOrAfter)) {
                            middleSelected = true
                            rightSelected = false
                        } else if (TextUtils.equals(
                                "及以后",
                                searchFilterData.graduateAgoOrAfter
                            )
                        ) {
                            middleSelected = false
                            rightSelected = true
                        }else {
                            middleSelected = false
                            rightSelected = false
                        }
                    }
                }

                BSearchFilterOptionType.FILTER_OPTION_MAJOR,
                BSearchFilterOptionType.FILTER_OPTION_INDUSTRY -> {
                    fileOptionData as SpinnerSearchFilterOptionData
                    if (fileOptionData.type == BSearchFilterOptionType.FILTER_OPTION_MAJOR) {
                        fileOptionData.txt = searchFilterData.profName
                    } else {
                        SearchActivity.mSelectedIndustries = null
                        fileOptionData.txt = StringUtil.join("、", searchFilterData.industryFields)
                    }
                }

                BSearchFilterOptionType.FILTER_OPTION_OUTSIDE,
                BSearchFilterOptionType.FILTER_OPTION_JOB_HOPPING -> {
                    fileOptionData as FlowSearchFilterOptionData
                    fileOptionData.options?.forEachIndexed { index, subDefaultOption ->
                        subDefaultOption as DefaultSearchFilterOptionData
                        if (subDefaultOption.type == BSearchFilterOptionType.FILTER_OPTION_OUTSIDE) {
                            if (TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), subDefaultOption.content)
                                && TextUtils.isEmpty(searchFilterData.famousOutSouring)
                            ) {
                                subDefaultOption.isSelected = true
                            } else {
                                subDefaultOption.isSelected =
                                    searchFilterData.famousOutSouring == subDefaultOption.content
                            }
                        } else {
                            if (TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), subDefaultOption.content)
                                && TextUtils.isEmpty(searchFilterData.jobHoppingSearchModel)
                            ) {
                                subDefaultOption.isSelected = true
                            } else {
                                subDefaultOption.isSelected =
                                    searchFilterData.jobHoppingSearchModel == subDefaultOption.content
                            }
                        }
                    }
                }

                BSearchFilterOptionType.MORE_FILTER_TITLE -> {
                    fileOptionData as TitleSearchFilterOptionData
                    fileOptionData.isSelected = searchFilterData.isMoreExpand
                }
            }
        }
    }

    /**
     * 展开&收起更多搜索
     */
    fun setExpandData(isExpanded: Boolean) {
        val moreIndex =
            adapterFilterDataList.indexOfLast { it.type == BSearchFilterOptionType.MORE_FILTER_TITLE }
        if (moreIndex == -1) {
            return
        }

        //更新更多标题项的状态
        searchFilterData?.isMoreExpand = isExpanded

        //1 展开
        if (isExpanded) {
            val moreBean = adapterFilterDataList.removeAt(moreIndex)
            notifyItemRemoved(moreIndex)

            adapterFilterDataList.addAll(adapterFilterExpandSuffixDataList)
            notifyItemRangeInserted(moreIndex, adapterFilterExpandSuffixDataList.size)

            adapterFilterDataList.add(moreBean)
            notifyItemInserted(moreIndex + adapterFilterExpandSuffixDataList.size)

            //notifyDataSetChanged()
            return
        }

        //2 收起
        val iterator = adapterFilterDataList.iterator()
        while (iterator.hasNext()) {
            val searchFilterOptionData = iterator.next()
            if (BSearchHelper.filterTypeExpandSuffixList.indexOf(searchFilterOptionData.type) > -1) {
                iterator.remove()
            }
        }
        notifyDataSetChanged()
    }

    /**
     * 重置指定类型的选项
     */
    fun resetGoalType(type: String) {
        adapterFilterDataList.forEachIndexed { index, filterOptionData ->
            if (type == filterOptionData.type) {
                if (filterOptionData is FlowSearchFilterOptionData) {
                    filterOptionData.options?.forEach {
                        it.isSelected = false
                    }
                    //notifyItemChanged(index)
                } else if (filterOptionData.isSelected == true) {
                    filterOptionData.isSelected = false
                    //notifyItemChanged(index)
                }
            }
        }
        notifyDataSetChanged()
    }

    /***
     * 选中其它选项取消不限
     */
    fun resetGoalTypeNoLimit(type: String) {
        adapterFilterDataList.forEachIndexed { index, filterOptionData ->
            if (type == filterOptionData.type) {
                if (filterOptionData is FlowSearchFilterOptionData) {
                    filterOptionData.options?.forEach {
                        if (TextUtils.equals(
                                (it as DefaultSearchFilterOptionData).content,
                                ResourceUtils.getString(R.string.search_filter_any)
                            ) && it.isSelected
                        ) {
                            it.isSelected = false
                            notifyItemChanged(index)
                            return
                        }
                    }
                }

                if (filterOptionData.isSelected) {
                    if (filterOptionData is DefaultSearchFilterOptionData) {
                        if (TextUtils.equals(
                                ResourceUtils.getString(R.string.search_filter_any),
                                filterOptionData.content
                            )
                        ) {
                            filterOptionData.isSelected = false
                            notifyItemChanged(index)
                            return
                        }
                    }
                    if (filterOptionData is SalarySearchFilterOptionData) {
                        if (TextUtils.equals(
                                ResourceUtils.getString(R.string.search_filter_any),
                                filterOptionData.content
                            ) || TextUtils.equals("自定义", filterOptionData.content)
                        ) {
                            filterOptionData.isSelected = false
                            notifyItemChanged(index)
                            return
                        }
                    }
                }
            }
        }
    }

    fun flushUi(type: String) {
        val index = adapterFilterDataList.indexOfLast { type == it.type }
        if (index == -1) {
            return
        }
        if (BSearchFilterOptionType.FILTER_OPTION_INDUSTRY.equals(type) && ListUtil.isEmpty(
                SearchActivity.mSelectedIndustries
            )
        ) {
            (adapterFilterDataList[index] as? SpinnerSearchFilterOptionData)?.txt = null
        }
        notifyItemChanged(index)
    }

    /**
     * 设置是否显示 自定义薪资条
     */
    fun setShowCustomSalary(isShowCustomSalary: Boolean, salaryMin: Int, salaryMax: Int) {
        //1 找出最后一条薪资选项
        var lastSalaryIndex =
            adapterFilterDataList.indexOfLast { it.type == BSearchFilterOptionType.FILTER_OPTION_SALARY }
        if (lastSalaryIndex <= 0) {
            return
        }

        //2 判断下标+1对应位置的元素是否是自定义薪资模块
        val lastSalaryNextIndex = lastSalaryIndex + 1
        if (isShowCustomSalary) {
            //2.1 如果下标加+1超过当前列表，说明薪资是最后一项，则直接在增加一项
            if (lastSalaryNextIndex >= adapterFilterDataList.size) {
                adapterFilterDataList.add(
                    SlideSearchFilterOptionData(
                        type = BSearchFilterOptionType.SLIDE_FILTER_OPTION_SALARY,
                        typeTxt = BSearchFilterOptionType.TITLE_SALARY_TXT,
                        minValue = salaryMin,
                        maxValue = salaryMax
                    )
                )
                notifyItemInserted(lastSalaryNextIndex)
                return
            }
            //2.2 如果下标加+1就是当前项，直接刷新列表
            val lastSalaryNextBean = adapterFilterDataList.get(lastSalaryNextIndex)
            if (lastSalaryNextBean is SlideSearchFilterOptionData &&
                lastSalaryNextBean.type == BSearchFilterOptionType.SLIDE_FILTER_OPTION_SALARY
            ) {
                lastSalaryNextBean.apply {
                    minValue = salaryMin
                    maxValue = salaryMax
                }
                notifyItemChanged(lastSalaryNextIndex)
                return
            }

            //2.3 直接在lastSalaryNextIndex插入
            adapterFilterDataList.add(
                lastSalaryNextIndex, SlideSearchFilterOptionData(
                    type = BSearchFilterOptionType.SLIDE_FILTER_OPTION_SALARY,
                    typeTxt = BSearchFilterOptionType.TITLE_SALARY_TXT,
                    minValue = salaryMin,
                    maxValue = salaryMax
                )
            )
            notifyItemInserted(lastSalaryNextIndex)
            notifyItemRangeChanged(lastSalaryNextIndex, itemCount - lastSalaryNextIndex)
            return
        }


        //3 隐藏薪资滑条处理
        //3.1 列表中没有直接返回
        if (lastSalaryNextIndex >= adapterFilterDataList.size) {
            return
        }
        //3.2 列表中有删除
        val lastSalaryNextBean = adapterFilterDataList[lastSalaryNextIndex]
        if (lastSalaryNextBean is SlideSearchFilterOptionData &&
            lastSalaryNextBean.type == BSearchFilterOptionType.SLIDE_FILTER_OPTION_SALARY
        ) {
            adapterFilterDataList.removeAt(lastSalaryNextIndex)
            notifyItemRemoved(lastSalaryNextIndex)
            notifyItemRangeChanged(lastSalaryNextIndex, itemCount - lastSalaryNextIndex)
        }
    }

    override fun onAttachedToRecyclerView(recyclerView: RecyclerView) {
        val layoutManager = recyclerView.layoutManager
        if (layoutManager is GridLayoutManager) {
            (layoutManager as GridLayoutManager).spanSizeLookup =
                object : GridLayoutManager.SpanSizeLookup() {
                    override fun getSpanSize(position: Int): Int {
                        return when (getItemViewType(position)) {
                            R.layout.item_company_filter_default,
                            R.layout.item_company_filter_salary
                            -> 1

                            else -> 3
                        }
                    }
                }
        }
    }

    override fun getItemViewType(position: Int): Int {

        val searchFilterOptionData = adapterFilterDataList[position]
        //1 通用标题类型
        if (searchFilterOptionData.isCommonTitleType()) {
            return R.layout.item_filter_subtitle
        }

        //2 薪资标签
        if (searchFilterOptionData.isSalaryOption()) {
            return R.layout.item_company_filter_salary
        }

        //3 通用选项
        if (searchFilterOptionData.isCommonOption()) {
            return R.layout.item_company_filter_default
        }

        //4.1 滑块年龄选项
        if (searchFilterOptionData.isSlideAgeOption()) {
            return R.layout.item_position_filter_age_b
        }
        //4.2 滑块薪资选项
        if (searchFilterOptionData.isSlideSalaryOption()) {
            return R.layout.item_position_filter_salary_b
        }

        //5 毕业时间选项
        if (searchFilterOptionData.isGraduateOption()) {
            return R.layout.item_position_graduate_b
        }
        //6 专业选项
        if (searchFilterOptionData.isMajorOption()) {
            return R.layout.item_position_major_b
        }

        //7 所在行业
        if (searchFilterOptionData.isIndustryOption()) {
            return R.layout.item_position_industry_b
        }

        //8 外包公司 || 跳槽频率  通用选择框内最多展示7个，少于等于7个字都是固定框； 超过7个字自适应，左右各30PX
        if (searchFilterOptionData.isFlowOption()) {
            return R.layout.item_position_flow_b
        }

        //9 更多搜索筛选条件
        if (searchFilterOptionData.isMoreTitleType()) {
            return R.layout.item_position_more_b
        }

        return R.layout.item_pos_type
    }

    override fun getItemCount(): Int {
        return adapterFilterDataList.size
    }

    public override fun resetAll() {
        //特殊处理，从外部页面传递过来的数据源
        if (!ListUtil.isEmpty(SearchActivity.mSelectedIndustries)){
            SearchActivity.mSelectedIndustries.clear()
            SearchActivity.mSelectedIndustries = null
        }
        recoverFilterOptions(adapterFilterDataList)
        recoverFilterOptions(adapterFilterExpandSuffixDataList)
        notifyDataSetChanged()
    }

    fun recoverFilterOptions(adapterFilterDataList: MutableList<BaseSearchFilterOptionData>) {
        adapterFilterDataList.forEachIndexed { index, filterOptionData ->
            if (filterOptionData is FlowSearchFilterOptionData) {
                filterOptionData.options?.forEach {
                    it.isSelected =
                        it is DefaultSearchFilterOptionData &&
                                TextUtils.equals(
                                    ResourceUtils.getString(R.string.search_filter_any),
                                    it.content
                                )
                }
                //notifyItemChanged(index)
            } else if (filterOptionData is SlideSearchFilterOptionData) {
                if (filterOptionData.type == BSearchFilterOptionType.SLIDE_FILTER_OPTION_AGE) {
                    filterOptionData.minValue = SearchConstants.MIN_AGE
                    filterOptionData.maxValue = SearchConstants.MAX_AGE
                } else {
                    filterOptionData.minValue = SearchConstants.MIN_SALARY
                    filterOptionData.maxValue = SearchConstants.MAX_SALARY
                }
            } else if (filterOptionData is GraduateSpinnerSearchFilterOptionData) {
                filterOptionData.txt = ""
                filterOptionData.middleSelected = false
                filterOptionData.rightSelected = false
            } else if (filterOptionData is SpinnerSearchFilterOptionData) {
                filterOptionData.txt = ""
                filterOptionData.isSelected = false
            } else {
                if (filterOptionData is DefaultSearchFilterOptionData && TextUtils.equals(
                        ResourceUtils.getString(R.string.search_filter_any),
                        filterOptionData.content
                    )
                ) {
                    filterOptionData.isSelected = true
                } else if (filterOptionData is SalarySearchFilterOptionData && TextUtils.equals(
                        ResourceUtils.getString(R.string.search_filter_any),
                        filterOptionData.content
                    )
                ) {
                    filterOptionData.isSelected = true
                } else {
                    //不重置更多的状态
                    if (filterOptionData.type != BSearchFilterOptionType.MORE_FILTER_TITLE) {
                        filterOptionData.isSelected = false
                    }
                }
                //notifyItemChanged(index)
            }
        }
    }

    /**
     * 选中-工作经验
     */
    fun getSelectExperience(): List<String?>? {
        return getDefaultSearchSelectOptions(BSearchFilterOptionType.FILTER_OPTION_EXPERIENCE)
    }

    fun getSelectPreference(): List<String?>? {
        return getDefaultSearchSelectOptions(BSearchFilterOptionType.FILTER_OPTION_BROWSE)
    }

    fun getSelectEducation(): List<String?>? {
        return getDefaultSearchSelectOptions(BSearchFilterOptionType.FILTER_OPTION_EDUCATION)
    }

    /**
     * 选中-求职状态
     */
    fun getSelectJobHuntingStatus(): List<String?>? {
        return getDefaultSearchSelectOptions(BSearchFilterOptionType.FILTER_OPTION_JOB_HUNTING)
    }

    fun getSelectGender(): List<String?>? {
        return getDefaultSearchSelectOptions(BSearchFilterOptionType.FILTER_OPTION_GENDER)
    }

    /**
     * 选中-院校
     */
    fun getSelectSchool(): List<String?>? {
        return getDefaultSearchSelectOptions(BSearchFilterOptionType.FILTER_OPTION_SCHOOL)
    }

    /**
     * 选中-名企
     */
    fun getSelectCompany(): List<String?>? {
        return getDefaultSearchSelectOptions(BSearchFilterOptionType.FILTER_OPTION_FAMOUS)
    }

    /**
     * 选中-空档期
     */
    fun getSelectPeriod(): String? {
        val periodList =
            getDefaultSearchSelectOptions(BSearchFilterOptionType.FILTER_OPTION_GAP_PERIOD)
        if (!ListUtil.isEmpty(periodList)) {
            return periodList?.get(0)
        }
        return ""
    }

    fun getDefaultSearchSelectOptions(type: String): List<String?>? {
        return completeAdapterFilterDataList
            .filter { type == it.type && it.isSelected }
            .map { (it as DefaultSearchFilterOptionData).content }
    }

    /**
     * 引导购买Vip，不够买点击“暂不升级, 去除高级筛选项”按钮，选择的选项中摘除付费选项
     */
    fun unSelectGoalOptions(needPayOptions: List<ShowV3SearchRes.PaidSearchFilter>?) {
        if (ListUtil.isEmpty(needPayOptions)) {
            return
        }
        completeAdapterFilterDataList.forEachIndexed { index, it ->
            //判断选中的属于付费选项
            if (it is FlowSearchFilterOptionData) {
                it.options?.forEach { subIt ->
                    unSelectNeedPayOptions(subIt, needPayOptions)
                }
            } else {
                unSelectNeedPayOptions(it, needPayOptions)
            }
        }
        notifyDataSetChanged()
    }

    /**
     * 取消选中的vip选项
     */
    private fun unSelectNeedPayOptions(
        filterOptionData: BaseSearchFilterOptionData,
        needPayOptions: List<ShowV3SearchRes.PaidSearchFilter>?
    ) {

        needPayOptions?.forEach {
            //if (TextUtils.equals(filterOptionData.type, it.name))
            if (TextUtils.equals(it.name, filterOptionData.typeTxt)) {
                if (filterOptionData is SlideSearchFilterOptionData) {
                    if (filterOptionData.type == BSearchFilterOptionType.SLIDE_FILTER_OPTION_AGE) {
                        filterOptionData.minValue = SearchConstants.MIN_AGE
                        filterOptionData.maxValue = SearchConstants.MAX_AGE
                    } else {
                        filterOptionData.minValue = SearchConstants.MIN_SALARY
                        filterOptionData.maxValue = SearchConstants.MAX_SALARY
                    }
                } else if (filterOptionData is GraduateSpinnerSearchFilterOptionData) {
                    filterOptionData.txt = ""
                    filterOptionData.middleSelected = false
                    filterOptionData.rightSelected = false
                } else if (filterOptionData is SpinnerSearchFilterOptionData) {
                    filterOptionData.txt = ""
                    filterOptionData.isSelected = false
                } else {
                    if (filterOptionData is DefaultSearchFilterOptionData) {
                        if (ListUtil.isEmpty(it.filters) || it.filters.indexOf(filterOptionData.content) >= 0) {
                            filterOptionData.isSelected = false
                        }
                    } else if (filterOptionData is SalarySearchFilterOptionData) {
                        if (ListUtil.isEmpty(it.filters) || it.filters.indexOf(filterOptionData.content) >= 0) {
                            filterOptionData.isSelected = false
                        }
                    }
                }
            }
        }
    }

    /**
     * 重置指定列表中选中的选项
     */
    fun getSelectSalaryValue(isMin: Boolean): Int? {
        val salarySelectList =
            adapterFilterDataList.filter { BSearchFilterOptionType.FILTER_OPTION_SALARY == it.type && it.isSelected }
        if (!ListUtil.isEmpty(salarySelectList)) {
            val salarySelectBean = salarySelectList.get(0) as SalarySearchFilterOptionData
            //1 非自定义的情况处理
            if (!TextUtils.equals("自定义", salarySelectBean.content)) {
                return if (isMin) salarySelectBean.salaryMin else salarySelectBean.salaryMax
            }
        }

        //2 自定义的情况处理
        val slideSalarySelectList =
            adapterFilterDataList.filter { BSearchFilterOptionType.SLIDE_FILTER_OPTION_SALARY == it.type && it.isSelected }
        if (!ListUtil.isEmpty(slideSalarySelectList)) {
            val salarySelectBean = slideSalarySelectList.get(0) as SlideSearchFilterOptionData

            return if (isMin) salarySelectBean.minValue else salarySelectBean.maxValue
        }

        return if (isMin) SearchConstants.MIN_SALARY else SearchConstants.MAX_SALARY
    }

    /**
     * 选中-薪资文本 用于匹配处理样式
     */
    fun getSelectSalaryTxt(): String? {
        val salarySelectList =
            completeAdapterFilterDataList.filter { BSearchFilterOptionType.FILTER_OPTION_SALARY == it.type && it.isSelected }
        if (!ListUtil.isEmpty(salarySelectList)) {
            val salarySelectBean = salarySelectList.get(0) as SalarySearchFilterOptionData
            return salarySelectBean.content
        }

        return null
    }


    fun getSelectAgeValue(isMin: Boolean): Int? {
        val ageSelectList =
            completeAdapterFilterDataList.filter { BSearchFilterOptionType.SLIDE_FILTER_OPTION_AGE == it.type }
        if (!ListUtil.isEmpty(ageSelectList)) {
            val ageSelectBean = ageSelectList.get(0) as SlideSearchFilterOptionData
            return if (isMin) ageSelectBean.minValue else ageSelectBean.maxValue
        }

        return if (isMin) SearchConstants.MIN_AGE else SearchConstants.MAX_AGE
    }

    fun getGraduateTime(): String? {
        val graduateTimeList =
            completeAdapterFilterDataList.filter { BSearchFilterOptionType.FILTER_OPTION_GRADUATE == it.type }
        if (!ListUtil.isEmpty(graduateTimeList)) {
            val graduateTimeBean = graduateTimeList.get(0) as GraduateSpinnerSearchFilterOptionData
            return graduateTimeBean.txt
        }

        return ""
    }

    /**
     * 毕业时间-及以前 及以后
     */
    fun getGraduateTimeBeforeOrAfter(): String? {
        val graduateTimeList =
            completeAdapterFilterDataList.filter { BSearchFilterOptionType.FILTER_OPTION_GRADUATE == it.type }
        if (!ListUtil.isEmpty(graduateTimeList)) {
            val graduateTimeBean = graduateTimeList.get(0) as GraduateSpinnerSearchFilterOptionData
            if (graduateTimeBean.middleSelected) {
                return "及以前"
            }

            if (graduateTimeBean.rightSelected) {
                return "及以后"
            }
        }

        return ""
    }

    /**
     * 选中的-跳槽频率
     */
    fun getJobHoppingSearchModel(): String? {
        return getFLowSearchSelectOptions(BSearchFilterOptionType.FILTER_OPTION_JOB_HOPPING)
    }

    /**
     * 选中的-外包公司
     */
    fun getFamousOutSouring(): String? {
        return getFLowSearchSelectOptions(BSearchFilterOptionType.FILTER_OPTION_OUTSIDE)
    }

    fun getFLowSearchSelectOptions(type: String): String? {
        val gobHoppingList = completeAdapterFilterDataList.filter { type == it.type }
        if (!ListUtil.isEmpty(gobHoppingList)) {
            val gobHoppingBeans = gobHoppingList.get(0) as? FlowSearchFilterOptionData
            val selectGobHoppingBeanS = gobHoppingBeans?.options?.filter { it.isSelected }
            if (!ListUtil.isEmpty(selectGobHoppingBeanS)) {
                return (selectGobHoppingBeanS?.get(0) as? DefaultSearchFilterOptionData)?.content
            }
        }

        return ""
    }

    /**
     * 选中的-行业
     */
    fun getIndustryFields(): List<String>? {
        val selectIndustryList = completeAdapterFilterDataList
            .filter { BSearchFilterOptionType.FILTER_OPTION_INDUSTRY == it.type }
        if (!ListUtil.isEmpty(selectIndustryList)) {
            val selectIndustryBean = selectIndustryList.get(0) as SpinnerSearchFilterOptionData
            if (!TextUtils.isEmpty(selectIndustryBean.txt)) {
                return selectIndustryBean.txt?.split("、")?.toList()
            }
        }

        return null
    }

    /**
     * 选中的-专业
     */
    fun getSelectProfName(): String? {
        val selectMajorList = completeAdapterFilterDataList
            .filter { BSearchFilterOptionType.FILTER_OPTION_MAJOR == it.type }
        if (!ListUtil.isEmpty(selectMajorList)) {
            val selectMajorBean = selectMajorList.get(0) as SpinnerSearchFilterOptionData
            return selectMajorBean.txt
        }
        return ""
    }

    fun getIsMoreExpand(): Boolean? {
        val titleMoreList = completeAdapterFilterDataList
            .filter { BSearchFilterOptionType.MORE_FILTER_TITLE == it.type }
        if (!ListUtil.isEmpty(titleMoreList)) {
            val titleMoreBean = titleMoreList.get(0) as? TitleSearchFilterOptionData
            return titleMoreBean?.isSelected
        }
        return false
    }

    /**
     * 是否位于屏幕-左 中 右  依次（设置边距使用）
     */
    override fun isDefaultClingLeft(position: Int): Boolean {
        if (!ListUtil.isListIndexLegal(adapterFilterDataList, position)) {
            return false
        }
        return adapterFilterDataList[position].isLocationLeft()
    }

    override fun isDefaultInMiddle(position: Int): Boolean {
        if (!ListUtil.isListIndexLegal(adapterFilterDataList, position)) {
            return false
        }
        return adapterFilterDataList[position].isLocationMiddle()
    }

    override fun isDefaultClingRight(position: Int): Boolean {
        if (!ListUtil.isListIndexLegal(adapterFilterDataList, position)) {
            return false
        }
        return adapterFilterDataList[position].isLocationRight()
    }

}