package com.lagou.lagouee.ui.adapter

import android.content.Context
import android.text.TextUtils
import android.view.ViewGroup
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.alpha.lagouapk.R
import com.common.adapter.BaseViewHolder
import com.common.adapter.listener.OnItemClick
import com.lagou.commonlibs.utils.ListUtil
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.lagouee.bean.jsonbean.search.ShowV3SearchRes
import com.lagou.lagouee.bean.search.BSearchFilterOptionType
import com.lagou.lagouee.bean.search.BaseSearchFilterOptionData
import com.lagou.lagouee.bean.search.DefaultSearchFilterOptionData
import com.lagou.lagouee.bean.search.FlowSearchFilterOptionData
import com.lagou.lagouee.bean.search.GraduateSpinnerSearchFilterOptionData
import com.lagou.lagouee.bean.search.SalarySearchFilterOptionData
import com.lagou.lagouee.bean.search.SlideSearchFilterOptionData
import com.lagou.lagouee.bean.search.SpinnerSearchFilterOptionData
import com.lagou.lagouee.bean.search.TitleSearchFilterOptionData
import com.lagou.lagouee.manager.BRequestConfigManager
import com.lagou.lagouee.ui.adapter.search.MoreTitleHolder
import com.lagou.lagouee.ui.adapter.search.NonPlusDefaultHolder
import com.lagou.lagouee.ui.adapter.search.NonPlusFlowHolder
import com.lagou.lagouee.ui.adapter.search.NonPlusGraduateHolder
import com.lagou.lagouee.ui.adapter.search.NonPlusIndustryHolder
import com.lagou.lagouee.ui.adapter.search.NonPlusMajorHolder
import com.lagou.lagouee.ui.adapter.search.NonPlusSalaryHolder
import com.lagou.lagouee.ui.adapter.search.NonPlusSubTitleHolderB
import com.lagou.lagouee.ui.adapter.search.OccupyHolder
import com.lagou.lagouee.ui.adapter.search.SlideAgeHolder
import com.lagou.lagouee.ui.adapter.search.SlideSalaryHolder

/**
 * Time：2024/5/29 11:12:34
 * Author：wangjunwei
 * Description：B端搜索，普通和Vip用户筛选项
 */
class CommonAndVipFilterMoreAdapter(context: Context) : BaseFilterMoreAdapter(context) {


    /**
     * 基础数据预处理
     */
    override  fun preprocessingOptions() {
        val searchV3SearchRes = BRequestConfigManager.getUseNewSearchConfig()
        val needPayOptions = searchV3SearchRes?.paidSearchFilters

        if (ListUtil.isEmpty(needPayOptions)) {
            return
        }

        completeAdapterFilterDataList.forEachIndexed { index, it ->
            //判断选中的属于付费选项
            if (it is FlowSearchFilterOptionData) {
                it.options?.forEach { subIt ->
                    nobleNeedPayOptions(subIt, needPayOptions)
                }
            } else {
                nobleNeedPayOptions(it, needPayOptions)
            }
        }
        notifyDataSetChanged()
    }


    /**
     * 选项上色具体逻辑
     */
    private fun nobleNeedPayOptions(
        filterOptionData: BaseSearchFilterOptionData,
        needPayOptions: List<ShowV3SearchRes.PaidSearchFilter>?
    ) {

        needPayOptions?.forEach {
            if (TextUtils.equals(it.name, filterOptionData.typeTxt)) {
                if (filterOptionData is SlideSearchFilterOptionData) {
                    if (filterOptionData.type == BSearchFilterOptionType.SLIDE_FILTER_OPTION_AGE) {
                        filterOptionData.isNobleStyle = true
                    } else {
                        filterOptionData.isNobleStyle = true
                    }
                } else if (filterOptionData is GraduateSpinnerSearchFilterOptionData) {
                    filterOptionData.isNobleStyle = true
                } else if (filterOptionData is SpinnerSearchFilterOptionData) {
                    filterOptionData.isNobleStyle = true
                } else {
                    if (filterOptionData is DefaultSearchFilterOptionData) {
                        if (!TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), filterOptionData.content)
                            && (ListUtil.isEmpty(it.filters) || it.filters.indexOf(filterOptionData.content) >= 0)) {
                            filterOptionData.isNobleStyle = true
                        } else {
                            filterOptionData.isNobleStyle = false
                        }
                    } else if (filterOptionData is SalarySearchFilterOptionData) {
                        if (!TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), filterOptionData.content)
                            && (ListUtil.isEmpty(it.filters) || it.filters.indexOf(filterOptionData.content) >= 0)) {
                            filterOptionData.isNobleStyle = true
                        } else {
                            filterOptionData.isNobleStyle = false
                        }
                    } else if (filterOptionData is TitleSearchFilterOptionData) {
                        //接口返回付费选项为空，则表示所有的选项都是Vip，标题上色
                        if (ListUtil.isEmpty(it.filters)) {
                            filterOptionData.isNobleStyle = true
                        }
                    }
                }
            }
        }
    }

    override fun onAttachedToRecyclerView(recyclerView: RecyclerView) {
        val layoutManager = recyclerView.layoutManager
        if (layoutManager is GridLayoutManager) {
            (layoutManager as GridLayoutManager).spanSizeLookup = object : GridLayoutManager.SpanSizeLookup() {
                override fun getSpanSize(position: Int): Int {
                    return when (getItemViewType(position)) {
                        R.layout.item_company_filter_default,
                        R.layout.item_company_filter_salary
                        -> 1
                        else -> 3
                    }
                }
            }
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        val itemView = mLayoutInflater.inflate(viewType, parent, false)
        return when (viewType) {
            R.layout.item_filter_subtitle -> NonPlusSubTitleHolderB(itemView)
            R.layout.item_company_filter_salary -> NonPlusSalaryHolder(itemView, this)
            R.layout.item_company_filter_default -> NonPlusDefaultHolder(itemView, this)
            R.layout.item_position_filter_age_b -> SlideAgeHolder(itemView, this)
            R.layout.item_position_filter_salary_b -> SlideSalaryHolder(itemView, this)
            R.layout.item_position_graduate_b -> NonPlusGraduateHolder(itemView, this)
            R.layout.item_position_major_b -> NonPlusMajorHolder(itemView, this)
            R.layout.item_position_industry_b -> NonPlusIndustryHolder(itemView, this)
            R.layout.item_position_flow_b -> NonPlusFlowHolder(itemView, this)
            R.layout.item_position_more_b -> MoreTitleHolder(itemView, this)
            else -> OccupyHolder(itemView, this)
        }
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        (holder as BaseViewHolder<BaseSearchFilterOptionData>).onBindViewHolder(
            holder.itemView,
            adapterFilterDataList.get(position), position, onItemClick
        )
    }
}