package com.lagou.lagouee.ui.adapter.search

import android.text.TextUtils
import android.view.View
import android.widget.TextView
import butterknife.BindView
import com.alpha.lagouapk.R
import com.alpha.lagouapk.tools.ComUtil
import com.common.adapter.BaseViewHolder
import com.common.adapter.listener.OnItemClick
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.view.WheelDialog
import com.lagou.lagouee.bean.search.GraduateSpinnerSearchFilterOptionData
import com.lagou.lagouee.ui.adapter.BaseFilterMoreAdapter

/**
 * Time：2024/5/7 16:22:25
 * Author：wangjunwei
 * Description：非plus 毕业时间选项
 *
 */
class NonPlusGraduateHolder(itemView: View, val plusFilterMoreAdapter: BaseFilterMoreAdapter) :
    BaseViewHolder<GraduateSpinnerSearchFilterOptionData>(itemView) {


    @BindView(R.id.tv_graduate_left)
    lateinit var tvGraduateLeft: TextView
    @BindView(R.id.view_line)
    lateinit var vmLine: View

    @BindView(R.id.tv_graduate_middle)
    lateinit var tvGraduateMiddle: TextView

    @BindView(R.id.tv_graduate_right)
    lateinit var tvGraduateRight: TextView

    override fun onBindViewHolder(
        view: View,
        spinnerSearchFilterOptionData: GraduateSpinnerSearchFilterOptionData,
        position: Int,
        onItemClick: OnItemClick<GraduateSpinnerSearchFilterOptionData>?
    ) {

        //1 默认样式
        if (!spinnerSearchFilterOptionData.isNobleStyle){
            tvGraduateLeft.setTextColor(ResourceUtils.getColor(R.color.color_333333))
            tvGraduateLeft.setHintTextColor(ResourceUtils.getColor(R.color.color_cccccc))
            vmLine.setBackgroundColor(ResourceUtils.getColor(R.color.color_e8e9eb))
        }else {
        //2 土豪金样式
            tvGraduateLeft.setTextColor(ResourceUtils.getColor(R.color.color_d2781f))
            tvGraduateLeft.setHintTextColor(ResourceUtils.getColor(R.color.color_E1B68C))
            vmLine.setBackgroundColor(ResourceUtils.getColor(R.color.color_E1B68C))
        }

        //1 初始化各个按钮文案
        tvGraduateLeft.text = spinnerSearchFilterOptionData.txt
        tvGraduateLeft.hint = spinnerSearchFilterOptionData.hintTxt
        tvGraduateMiddle.text = spinnerSearchFilterOptionData.middleTxt
        tvGraduateRight.text = spinnerSearchFilterOptionData.rightTxt
        if (!TextUtils.isEmpty(spinnerSearchFilterOptionData.txt)
            && !TextUtils.equals("不限", spinnerSearchFilterOptionData.txt)
        ) {
            tvGraduateMiddle.isEnabled = true
            tvGraduateRight.isEnabled = true
            tvGraduateMiddle.isSelected = spinnerSearchFilterOptionData.middleSelected
            tvGraduateRight.isSelected = spinnerSearchFilterOptionData.rightSelected
        } else {
            tvGraduateMiddle.isEnabled = false
            tvGraduateRight.isEnabled = false
            tvGraduateMiddle.isSelected = false
            tvGraduateRight.isSelected = false
        }

        //2 各个按钮的点击事件
        tvGraduateLeft.setOnClickListener {
            graduateWheelDialog(spinnerSearchFilterOptionData, position, onItemClick)
        }

        //3 及以前 及以后单选
        tvGraduateMiddle.setOnClickListener {
            if (spinnerSearchFilterOptionData.middleSelected) {
                spinnerSearchFilterOptionData.middleSelected = false
                tvGraduateMiddle.isSelected = false
                plusFilterMoreAdapter.notifyItemChanged(position)
                return@setOnClickListener
            }

            spinnerSearchFilterOptionData.middleSelected = true
            spinnerSearchFilterOptionData.rightSelected = false
            tvGraduateMiddle.isSelected = true
            tvGraduateRight.isSelected = false
            plusFilterMoreAdapter.notifyItemChanged(position)
        }
        tvGraduateRight.setOnClickListener {
            if (spinnerSearchFilterOptionData.rightSelected) {
                spinnerSearchFilterOptionData.rightSelected = false
                tvGraduateRight.isSelected = false
                plusFilterMoreAdapter.notifyItemChanged(position)
                return@setOnClickListener
            }
            spinnerSearchFilterOptionData.rightSelected = true
            spinnerSearchFilterOptionData.middleSelected = false
            tvGraduateRight.isSelected = true
            tvGraduateMiddle.isSelected = false
            plusFilterMoreAdapter.notifyItemChanged(position)
        }


        onItemClick?.onClick(spinnerSearchFilterOptionData, position)
    }

    private fun graduateWheelDialog(
        spinnerSearchFilterOptionData: GraduateSpinnerSearchFilterOptionData,
        position: Int,
        onItemClick: OnItemClick<GraduateSpinnerSearchFilterOptionData>?
    ) {
        WheelDialog(mContext).apply {
            GraduateWheelStrategy()
            builder(
                "请选择毕业年份", R.id.tv_graduate_left, ComUtil.getGraduateOptions(),
                ComUtil.getGraduateCurrent(), null, WheelDialog.MIN
            )
            setOnDataPicListener { _, data ->
                if (data.size < 1) {
                    return@setOnDataPicListener
                }
                tvGraduateLeft.text = data[0]

                onItemClick?.onClick(spinnerSearchFilterOptionData, position)
                
                spinnerSearchFilterOptionData.txt = data[0]
                plusFilterMoreAdapter.notifyItemChanged(position)
            }
        }.show()
    }

    override fun getTitle(): String {
        return "毕业时间选项"
    }

}