package com.lagou.lagouee.ui.adapter.search

import android.text.TextUtils
import android.view.View
import android.widget.TextView
import com.alpha.lagouapk.R
import com.common.adapter.BaseViewHolder
import com.common.adapter.listener.OnItemClick
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.lagouee.bean.search.SalarySearchFilterOptionData
import com.lagou.lagouee.bean.search.SearchConstants
import com.lagou.lagouee.ui.adapter.BaseFilterMoreAdapter
import me.devilsen.czxing.compat.ContextCompat

/**
 * Time：2024/5/29 15:21:42
 * Author：wangjunwei
 * Description：非plus 薪资类型选项，特殊处理（点击自定义显示自定义薪资条）
 *
 */
class NonPlusSalaryHolder(itemView: View, val plusFilterMoreAdapter: BaseFilterMoreAdapter) : BaseViewHolder<SalarySearchFilterOptionData>(itemView) {

    var tvLabel: TextView

    init {
        tvLabel = itemView as TextView
    }

    override fun onBindViewHolder(
        view: View,
        filterOptionData: SalarySearchFilterOptionData,
        position: Int,
        onItemClick: OnItemClick<SalarySearchFilterOptionData>?
    ) {

        if (!filterOptionData.isNobleStyle){
            tvLabel.background = ResourceUtils.getDrawable(R.drawable.selector_home_filter_label_bg)
            tvLabel.setTextColor(ContextCompat.getColorStateList(itemView.context, R.color.selector_resume_manager_text_color))
        }else {
            tvLabel.background = ResourceUtils.getDrawable(R.drawable.selector_fff9f0_solidfff9f0_borderd2781f_bg)
            tvLabel.setTextColor(ContextCompat.getColorStateList(itemView.context,R.color.color_d2781f))
        }

        tvLabel.isSelected = filterOptionData.isSelected
        tvLabel.text = filterOptionData.content
        tvLabel.setOnClickListener { v: View ->

            //1 如果是取消筛选
            if (filterOptionData.isSelected){
                handleShowChange(filterOptionData, position)
                onItemClick?.onClick(filterOptionData, position)
                return@setOnClickListener
            }

            //2 判断是否单选，如果是先重置其它选项（多选自定义也重置其它选项）
            if (!filterOptionData.isSupportMultiple){
                plusFilterMoreAdapter.resetGoalType(filterOptionData.type)
            }else{
                //3 如果是多选，选中不限也要先重置其它选项
                if (TextUtils.equals(tvLabel.text, "不限") || TextUtils.equals(tvLabel.text, "自定义")){
                    plusFilterMoreAdapter.resetGoalType(filterOptionData.type)
                }else {
                    //3 选中不是不限选项，需要把不限取消掉
                    plusFilterMoreAdapter.resetGoalTypeNoLimit(filterOptionData.type)
                }
            }

            handleShowChange(filterOptionData, position)
            onItemClick?.onClick(filterOptionData, position)
        }
    }

    private fun handleShowChange(
        filterOptionData: SalarySearchFilterOptionData,
        position: Int
    ) {
        //2 选中标签样式变化
        filterOptionData.isSelected = !filterOptionData.isSelected
        tvLabel.isSelected = filterOptionData.isSelected
        plusFilterMoreAdapter.notifyItemChanged(position)

        //3 点击自定义
        if (TextUtils.equals(tvLabel.text, "自定义")) {
            plusFilterMoreAdapter.setShowCustomSalary(
                tvLabel.isSelected,
                SearchConstants.MIN_SALARY,
                SearchConstants.MAX_SALARY
            )
        }else {
            plusFilterMoreAdapter.setShowCustomSalary(
                false,
                SearchConstants.MIN_SALARY,
                SearchConstants.MAX_SALARY
            )
        }
    }

    override fun getTitle(): String {
       return "vip 通用选项"
    }
}