package com.lagou.lagouee.ui.adapter.search
import android.content.Context
import android.text.TextUtils
import android.util.AttributeSet
import android.view.Gravity
import android.view.View
import android.widget.TextView
import androidx.core.content.ContextCompat
import com.alpha.lagouapk.R
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.commonlibs.view.FlowLayout
import com.lagou.lagouee.bean.search.BaseSearchFilterOptionData
import com.lagou.lagouee.bean.search.DefaultSearchFilterOptionData
import com.lagou.socketchannel.interfaces.CallBack

/**
 * Time：2024/5/9 01:51:17
 * Author：wangjunwei
 * Description：跳槽和外包公司
 */
class SearchMoreFlowLayout : FlowLayout {

    protected var maxLabelLines = 0 // 单个标签行数

    protected var maxLinesSuffix = 0 // 整个 布局行数

    protected var txtSize = 0
    protected var txtLeftPadding = 0
    protected var txtLeftPaddingBig = ResourceUtils.getDimenSize(R.dimen.dp_41)
    protected var txtTopPadding = 0
    private var horizontalSpace = 0
    private var verticalSpace = 0
    private var maxWidth = 0

    constructor(context: Context) : super(context) {
        init(context, null)
    }

    constructor(context: Context, attrs: AttributeSet?) : super(context, attrs) {
        init(context, attrs)
    }

    private fun init(context: Context, attrs: AttributeSet?) {
        val ta = context.obtainStyledAttributes(attrs, R.styleable.FlexBoxTextView)
        maxLabelLines = ta.getInteger(R.styleable.FlexBoxTextView_labelMaxLines, 1)
        maxLinesSuffix = ta.getInteger(R.styleable.FlexBoxTextView_maxLines, 1)
        txtSize = ta.getInteger(R.styleable.FlexBoxTextView_txtSize, 13)
        txtLeftPadding = ta.getDimension(R.styleable.FlexBoxTextView_txtLeftPadding,
            ResourceUtils.getDimenSize(R.dimen.dp_15).toFloat()
        ).toInt()
        txtTopPadding = ta.getDimension(R.styleable.FlexBoxTextView_txtTopPadding,
            ResourceUtils.getDimenSize(R.dimen.dp_10_05).toFloat()
        ).toInt()
        horizontalSpace = ta.getDimensionPixelSize(R.styleable.FlexBoxTextView_horizonSpace, -1)
        verticalSpace = ta.getDimensionPixelSize(R.styleable.FlexBoxTextView_verticalSpace, -1)
        maxWidth = ta.getDimensionPixelSize(R.styleable.FlexBoxTextView_maxWidth, -1)
        if (horizontalSpace != -1) {
            setHorizontalSpacing(horizontalSpace)
        }
        if (verticalSpace != -1) {
            setVerticalSpacing(verticalSpace)
        }
        ta.recycle()
        setMaxLines(maxLinesSuffix)
    }

    fun fillLabelView(labels: List<BaseSearchFilterOptionData>?, callback: CallBack<BaseSearchFilterOptionData?>) {
        if (labels.isNullOrEmpty()) {
            visibility = GONE
            return
        }
        visibility = VISIBLE
        val viewCount = childCount
        val textCount = labels.size
        // 多退少补
        if (viewCount < textCount) {
            val count = textCount - viewCount
            for (i in 0 until count) {
                addView(generateNewLabelView())
            }
        } else if (viewCount > textCount) {
            for (i in viewCount downTo textCount + 1) {
                getChildAt(i - 1).visibility = GONE
            }
        }

        //2 根据数据更新样式
        labels.forEachIndexed{index, it ->
            val label = it as? DefaultSearchFilterOptionData
            if (label != null) {
                val labelView = getChildAt(index) as TextView

                //1 普通样式
                if(!label.isNobleStyle){
                    labelView.setBackgroundResource(R.drawable.selector_home_filter_label_bg)
                    labelView.setTextColor(ContextCompat.getColorStateList(context, R.color.selector_resume_manager_text_color))
                }else {
                    //2 土豪金样式
                    labelView.setBackgroundResource(R.drawable.selector_fff9f0_solidfff9f0_borderd2781f_bg)
                    labelView.setTextColor(ResourceUtils.getColor(R.color.color_d2781f))
                }

                labelView.isSelected = label.isSelected
                labelView.visibility = VISIBLE
                labelView.text = label.content

                label.content?.apply{
                    if (length <= 7){
                        labelView.setPadding(txtLeftPaddingBig, txtTopPadding, txtLeftPaddingBig, txtTopPadding)
                    }else {
                        labelView.setPadding(txtLeftPadding, txtTopPadding, txtLeftPadding, txtTopPadding)
                    }
                }

                labelView.tag = label
                labelView.setOnClickListener {
                    updateStyle(it, it.tag as? DefaultSearchFilterOptionData, labels)
                    callback.onCallBack(it.tag as? DefaultSearchFilterOptionData)
                }
            }
        }
    }

    private fun updateStyle(currentLabelView: View, selectLabel: DefaultSearchFilterOptionData?, labels: List<BaseSearchFilterOptionData>?){
        if (selectLabel == null){
            return
        }

        //0 如果是选中状态，则取消选中
        if (selectLabel.isSelected){
            selectLabel.isSelected = false;
            currentLabelView.isSelected = false
            return
        }

        //1 先重置所有的筛选项
        labels?.forEachIndexed {index, it ->
            it.isSelected = false
            val labelView = getChildAt(index) as TextView
            labelView.isSelected = false
        }

        // 2 根据选中的数据更新样式
        labels?.forEachIndexed {index, it ->
            if (TextUtils.equals((it as DefaultSearchFilterOptionData).content, selectLabel.content)){
                it.isSelected = true
                val labelView = getChildAt(index) as TextView
                labelView.isSelected = true
                return
            }
        }
    }
    fun generateNewLabelView(): TextView {
        val labelView = TextView(context)
        labelView.setTextColor(ContextCompat.getColorStateList(context, R.color.selector_resume_manager_text_color))
        labelView.gravity = Gravity.CENTER
        labelView.textSize = txtSize.toFloat()
        labelView.setBackgroundResource(R.drawable.selector_home_filter_label_bg)
        labelView.maxLines = maxLabelLines
        labelView.ellipsize = TextUtils.TruncateAt.END
        labelView.setPadding(txtLeftPadding, txtTopPadding, txtLeftPadding, txtTopPadding)
        if (maxWidth != -1) {
            labelView.maxWidth = maxWidth
        }
        return labelView
    }
}