package com.lagou.lagouee.ui.search.view

import android.content.Context
import android.text.TextUtils
import android.widget.Button
import android.widget.ImageView
import butterknife.BindView
import com.alpha.lagouapk.R
import com.common.adapter.listener.OnItemClick
import com.lagou.baselib.BaseActivity
import com.lagou.commonlibs.inter.OnSingleMethodNoParameterListener
import com.lagou.commonlibs.utils.ListUtil
import com.lagou.commonlibs.utils.ResourceUtils
import com.lagou.lagouee.bean.jsonbean.search.ShowV3SearchRes
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_BROWSE_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_EDUCATION_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_EXPERIENCE_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_FAMOUS_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_GAP_PERIOD_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_GENDER_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_GRADUATE_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_INDUSTRY_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_JOB_HOPPING_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_JOB_HUNTING_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_MAJOR_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_OUTSIDE_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_SALARY_TXT
import com.lagou.lagouee.bean.search.BSearchFilterOptionType.Companion.TITLE_SCHOOL_TXT
import com.lagou.lagouee.bean.search.BaseSearchFilterOptionData
import com.lagou.lagouee.bean.search.SearchFilterData
import com.lagou.lagouee.manager.BRequestConfigManager
import com.lagou.lagouee.ui.adapter.BaseFilterMoreAdapter
import com.lagou.lagouee.ui.adapter.CommonAndVipFilterMoreAdapter
import com.lagou.lagouee.utils.DialogUtils
import com.lagou.lagouee.utils.IntentUtils
import java.util.Arrays

/**
 * Time：2024/5/28 15:06:10
 * Author：wangjunwei
 * Description：非拉勾加-更多筛选主界面样式
 *
 */
class CommonAndVipFilterMoreLayout(context: Context?) : FilterMoreBaseLayout(context) {

    @BindView(R.id.filter_confirm)
    lateinit var btnFilterConfirm: Button

    @BindView(R.id.image_flag)
    lateinit var imageFlag: ImageView

    override fun createAdapter(context: Context): BaseFilterMoreAdapter {
        return CommonAndVipFilterMoreAdapter(context)
    }

    override fun init() {
        super.init()
        initListener()
    }

    private fun initListener() {
        filterAdapter?.setOnItemClickListener(object : OnItemClick<BaseSearchFilterOptionData> {
            override fun onClick(t: BaseSearchFilterOptionData?, position: Int) {
                handleVipOutStyle()
            }
        })
    }

    override fun setFilterSelected(searchFilterData: SearchFilterData?) {
        super.setFilterSelected(searchFilterData)
        handleVipOutStyle()
    }

    /**
     * 整体页面的界面风格
     */
    private fun handleVipOutStyle() {
        btnFilterConfirm.setBackgroundResource(R.drawable.selector_0db790_009978)
        imageFlag.visibility = GONE
        btnFilterConfirm.text = ResourceUtils.getString(R.string.alert_btn_queding)

        //1 判断当前选中的是否有Vip选项
        val selectPayOptions = extractNeedPayOptions()
        if (ListUtil.isEmpty(selectPayOptions)) {
            return
        }

        //2 选择的选项有付费选项&有体验次数，文案为体验多少，按钮颜色为绿色
        getSearchV3SearchRes()?.trialCount?.let {
            if (it > 0) {
                btnFilterConfirm.text = getSearchV3SearchRes()?.btnTxt
                return
            }
        }

        //3 非Vip直接返回，按钮一律绿色
        if(getSearchV3SearchRes()?.isVipType != true){
            return
        }
        btnFilterConfirm.text = getSearchV3SearchRes()?.btnTxt
        btnFilterConfirm.setBackgroundResource(R.drawable.shape_rect_d69950_e59a3f)
        //vip 图标
        imageFlag.visibility = VISIBLE
    }


    /**
     * 点击确认搜索，执行搜索后判断是否需要触发购买Vip或者plus
     */
    override fun showSearchDialog() {

        //0 判断是否不能买vip（风险账号，只能跳到拉勾+介绍页）
        if (getSearchV3SearchRes()?.isOnlyUpgradePlus == true){
            IntentUtils.startLagouWebViewActivity(context, getSearchV3SearchRes()?.upgradeUrl)
            return
        }

        //1 需要购买则弹出升级Vip弹窗，同时中断后续搜索流程
        //  引导购买Vip弹窗，抽取筛选项中需要付费的部分
        // 1.1 获取选中的付费选项
        val selectPayOptions = extractNeedPayOptions()
        // 1.2 如果为空，说明选中的没有付费选项，继续执行搜索流程
        if (ListUtil.isEmpty(selectPayOptions)) {
            return
        }

        //2 弹出Vip引导购买弹窗
        DialogUtils.showSearchVipGuideDialog(context as BaseActivity, getSearchV3SearchRes(),
            selectPayOptions, object : OnSingleMethodNoParameterListener {
                override fun onCallBack() {
                    //1 去除付费选项继续筛选
                    filterAdapter?.unSelectGoalOptions(getSearchV3SearchRes()?.paidSearchFilters)
                    //2 执行搜素操作
                    btnFilterConfirm.callOnClick()
                    cancel()
                }
            })
    }

    /**
     * 抽取选中的付费选项
     */
    private fun extractNeedPayOptions(): ArrayList<String?> {
        val needPayOptions = getSearchV3SearchRes()?.paidSearchFilters
        val resultPayOptions = arrayListOf<String?>()

        needPayOptions?.forEachIndexed { index, paidSearchFilter ->
            paidSearchFilter?.let {
                //1 工作经验
                when (it.name) {
                    TITLE_EXPERIENCE_TXT -> {
                        realSelectOption(it, filterAdapter?.getSelectExperience(), resultPayOptions)
                    }

                    TITLE_EDUCATION_TXT -> {
                        realSelectOption(it, filterAdapter?.getSelectEducation(), resultPayOptions)
                    }

                    TITLE_SCHOOL_TXT -> {
                        realSelectOption(it, filterAdapter?.getSelectSchool(), resultPayOptions)
                    }
                    //TITLE_AGE_TXT
                    TITLE_SALARY_TXT -> {
                        realSelectOption(
                            it,
                            Arrays.asList(filterAdapter?.getSelectSalaryTxt()),
                            resultPayOptions
                        )
                    }

                    TITLE_GENDER_TXT -> {
                        realSelectOption(it, filterAdapter?.getSelectGender(), resultPayOptions)
                    }

                    TITLE_GRADUATE_TXT -> {
                        realSelectOption(
                            it, Arrays.asList(
                                filterAdapter?.getGraduateTime(),
                                filterAdapter?.getGraduateTimeBeforeOrAfter()
                            ), resultPayOptions
                        )
                    }

                    TITLE_MAJOR_TXT -> {
                        realSelectOption(
                            it, Arrays.asList(filterAdapter?.getSelectProfName()), resultPayOptions
                        )
                    }

                    TITLE_JOB_HUNTING_TXT -> {
                        realSelectOption(
                            it,
                            filterAdapter?.getSelectJobHuntingStatus(),
                            resultPayOptions
                        )
                    }

                    TITLE_INDUSTRY_TXT -> {
                        realSelectOption(it, filterAdapter?.getIndustryFields(), resultPayOptions)
                    }

                    TITLE_OUTSIDE_TXT -> {
                        realSelectOption(
                            it,
                            Arrays.asList(filterAdapter?.getFamousOutSouring()),
                            resultPayOptions
                        )
                    }

                    TITLE_JOB_HOPPING_TXT -> {
                        realSelectOption(
                            it,
                            Arrays.asList(filterAdapter?.getJobHoppingSearchModel()),
                            resultPayOptions
                        )
                    }

                    TITLE_GAP_PERIOD_TXT -> {
                        realSelectOption(
                            it,
                            Arrays.asList(filterAdapter?.getSelectPeriod()),
                            resultPayOptions
                        )
                    }

                    TITLE_FAMOUS_TXT -> {
                        realSelectOption(it, filterAdapter?.getSelectCompany(), resultPayOptions)
                    }

                    TITLE_BROWSE_TXT -> {
                        realSelectOption(it, filterAdapter?.getSelectPreference(), resultPayOptions)
                    }

                    else -> {}
                }
            }
        }

        return resultPayOptions
    }

    /**
     * 提取实际选中的选项
     */
    private fun realSelectOption(
        it: ShowV3SearchRes.PaidSearchFilter,
        selectOptions: List<String?>?,
        resultPayOptions: ArrayList<String?>
    ) = selectOptions?.forEach { option ->
        if (ListUtil.isEmpty(it.filters) || it.filters.contains(option)) {
            if(!TextUtils.isEmpty(option) && !TextUtils.equals(ResourceUtils.getString(R.string.search_filter_any), option)){
                resultPayOptions.add(option)
            }
        }
    }


    private fun getSearchV3SearchRes(): ShowV3SearchRes? {
        return BRequestConfigManager.getUseNewSearchConfig()
    }
}