package com.lagou.lagouee.ui.search.view

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.OnClick
import com.alpha.lagouapk.R
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.lagouee.bean.search.NewFilterMoreData
import com.lagou.lagouee.bean.search.SearchFilterData
import com.lagou.lagouee.ui.adapter.BaseFilterMoreAdapter
import com.lagou.lagouee.ui.search.FilterDecoration

/**
 * Time：2024/5/8 18:05:04
 * Author：wangjunwei
 * Description：B端更多筛选项，View基类，普通FilterMoreLayout VipFilterMoreLayout
 */
abstract class FilterMoreBaseLayout(context: Context?) : FilterBaseLayout<NewFilterMoreData?>(context) {


    @BindView(R.id.rv_search_filter)
    lateinit var rvSearchFilter: RecyclerView

    protected var filterAdapter: BaseFilterMoreAdapter? = null
    private var filterMoreData: NewFilterMoreData? = null

    override fun getViewContent(): View {
        return this
    }

    override fun resetFilter() {
        //codeman todo 临时注释掉，后续确定下是否能注释
        //filterAdapter?.resetAll()
    }

    open fun flushUi(type: String) {
        filterAdapter?.flushUi(type)
    }

    override fun init() {
        LayoutInflater.from(context).inflate(R.layout.layout_filter_search_more, this)
        ButterKnife.bind(this)
        initFilterView()
    }

    private fun initFilterView() {
        val gridLayoutManager = GridLayoutManager(context, 3)
        rvSearchFilter.apply {
            layoutManager = gridLayoutManager
            setHasFixedSize(true)
            filterAdapter = createAdapter(context)
            addItemDecoration(FilterDecoration(filterAdapter, context))

            adapter = filterAdapter
        }
    }

    override fun initData(): NewFilterMoreData? {
        filterMoreData = NewFilterMoreData()
        // 感觉可以注释掉
        //filterAdapter?.notifyDataSetChanged()
        return filterMoreData
    }

    override fun setSearchFilterData(searchFilterData: SearchFilterData?) {
        super.setSearchFilterData(searchFilterData)
        filterAdapter?.setSearchFilter(searchFilterData)
    }

    override fun setFilterSelected(searchFilterData: SearchFilterData?) {
        filterAdapter?.setSearchFilter(searchFilterData)
    }

    @OnClick(R.id.filter_clear, R.id.filter_confirm, R.id.transparent_filter_cancle)
    fun onViewClicked(view: View) {
        when (view.id) {
            R.id.filter_clear -> {
                setFilterSelected(null)
            }

            R.id.filter_confirm -> {
                cancel()
                if (onDismissListener != null) {
                    extractSelectOptions()
                    onDismissListener.onConfirm(mData)
                    AnalyticHelper.getInstance().sendClickInfo("fR00", "1s6h")
                }
            }

            R.id.transparent_filter_cancle -> cancel()
            else -> {}
        }
    }

    /**
     * 抽取选中的选项
     */
    protected fun extractSelectOptions() {
        mData?.apply {
            experience = filterAdapter?.getSelectExperience()
            preference = filterAdapter?.getSelectPreference()
            education = filterAdapter?.getSelectEducation()
            salaryLower = filterAdapter?.getSelectSalaryValue(true)
            salaryUpper = filterAdapter?.getSelectSalaryValue(false)
            selectSalaryTxt = filterAdapter?.getSelectSalaryTxt()
            jobHuntingStatus = filterAdapter?.getSelectJobHuntingStatus()
            ageLower = filterAdapter?.getSelectAgeValue(true)
            ageUpper = filterAdapter?.getSelectAgeValue(false)
            gender = filterAdapter?.getSelectGender()
            school = filterAdapter?.getSelectSchool()
            company = filterAdapter?.getSelectCompany()
            graduateTime = filterAdapter?.getGraduateTime()
            graduateAgoOrAfter = filterAdapter?.getGraduateTimeBeforeOrAfter()
            jobHoppingSearchModel = filterAdapter?.getJobHoppingSearchModel()
            famousOutSourcing = filterAdapter?.getFamousOutSouring()
            industryFields = filterAdapter?.getIndustryFields()
            period = filterAdapter?.getSelectPeriod()
            profName = filterAdapter?.getSelectProfName()
            isMoreExpand = filterAdapter?.getIsMoreExpand()
        }
    }

    /**
     * 创建所需要的适配器
     */
    protected abstract fun createAdapter(context: Context): BaseFilterMoreAdapter

    open fun showSearchDialog(){

    }
}